plugin_host_web

package
v0.51.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: Apache-2.0 Imports: 32 Imported by: 0

Documentation

Index

Constants

const ConfigID = ControllerID

ConfigID is the config identifier.

const ControllerID = "bldr/plugin/host/web"

ControllerID is the process host controller ID.

const QuickJSConfigID = WebQuickJSHostControllerID

QuickJSConfigID is the config identifier for the QuickJS plugin host.

const WebQuickJSHostControllerID = "bldr/plugin/host/web-quickjs"

WebQuickJSHostControllerID is the quickjs web host controller ID.

Variables

var Version = semver.MustParse("0.0.1")

Version is the version of this controller.

Functions

This section is empty.

Types

type Config

type Config struct {

	// WebRuntimeId is the identifier of the web runtime.
	WebRuntimeId string `protobuf:"bytes,1,opt,name=web_runtime_id,json=webRuntimeId,proto3" json:"webRuntimeId,omitempty"`
	// ForceDedicatedWorkers overrides the default SharedWorker mode to use
	// dedicated Workers instead. Useful for testing with Playwright which
	// can capture console output from dedicated workers but not shared.
	ForceDedicatedWorkers bool `protobuf:"varint,2,opt,name=force_dedicated_workers,json=forceDedicatedWorkers,proto3" json:"forceDedicatedWorkers,omitempty"`
	// contains filtered or unexported fields
}

Config is the WebWorker PluginHost controller configuration.

func NewConfig

func NewConfig(webRuntimeID string) *Config

NewConfig constructs a new controller config. Sets the most important fields only.

func (*Config) CloneMessageVT

func (m *Config) CloneMessageVT() protobuf_go_lite.CloneMessage

func (*Config) CloneVT

func (m *Config) CloneVT() *Config

func (*Config) EqualMessageVT

func (this *Config) EqualMessageVT(thatMsg any) bool

func (*Config) EqualVT

func (this *Config) EqualVT(that *Config) bool

func (*Config) EqualsConfig

func (c *Config) EqualsConfig(other config.Config) bool

EqualsConfig checks if the config is equal to another.

func (*Config) GetConfigID

func (c *Config) GetConfigID() string

GetConfigID returns the unique string for this configuration type. This string is stored with the encoded config.

func (*Config) GetForceDedicatedWorkers

func (x *Config) GetForceDedicatedWorkers() bool

func (*Config) GetWebRuntimeId

func (x *Config) GetWebRuntimeId() string

func (*Config) MarshalJSON

func (x *Config) MarshalJSON() ([]byte, error)

MarshalJSON marshals the Config to JSON.

func (*Config) MarshalProtoJSON

func (x *Config) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the Config message to JSON.

func (*Config) MarshalProtoText

func (x *Config) MarshalProtoText() string

func (*Config) MarshalToSizedBufferVT

func (m *Config) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*Config) MarshalToVT

func (m *Config) MarshalToVT(dAtA []byte) (int, error)

func (*Config) MarshalVT

func (m *Config) MarshalVT() (dAtA []byte, err error)

func (*Config) ProtoMessage

func (*Config) ProtoMessage()

func (*Config) Reset

func (x *Config) Reset()

func (*Config) SizeVT

func (m *Config) SizeVT() (n int)

func (*Config) String

func (x *Config) String() string

func (*Config) UnmarshalJSON

func (x *Config) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the Config from JSON.

func (*Config) UnmarshalProtoJSON

func (x *Config) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the Config message from JSON.

func (*Config) UnmarshalVT

func (m *Config) UnmarshalVT(dAtA []byte) error

func (*Config) Validate

func (c *Config) Validate() error

Validate validates the configuration. This is a cursory validation to see if the values "look correct."

type Factory

type Factory struct {
	// contains filtered or unexported fields
}

Factory constructs a plugin host.

func NewFactory

func NewFactory(bus bus.Bus) *Factory

NewFactory builds the factory.

func (*Factory) Construct

func (t *Factory) Construct(
	ctx context.Context,
	conf config.Config,
	opts controller.ConstructOpts,
) (controller.Controller, error)

Construct constructs the associated controller given configuration.

func (*Factory) ConstructConfig

func (t *Factory) ConstructConfig() config.Config

ConstructConfig constructs an instance of the controller configuration.

func (*Factory) GetConfigID

func (t *Factory) GetConfigID() string

GetConfigID returns the configuration ID for the controller.

func (*Factory) GetControllerID

func (t *Factory) GetControllerID() string

GetControllerID returns the unique ID for the controller.

func (*Factory) GetVersion

func (t *Factory) GetVersion() semver.Version

GetVersion returns the version of this controller.

type QuickJSConfig

type QuickJSConfig struct {

	// WebRuntimeId is the identifier of the web runtime.
	WebRuntimeId string `protobuf:"bytes,1,opt,name=web_runtime_id,json=webRuntimeId,proto3" json:"webRuntimeId,omitempty"`
	// ForceDedicatedWorkers overrides the default SharedWorker mode to use
	// dedicated Workers instead. Useful for testing with Playwright which
	// can capture console output from dedicated workers but not shared.
	ForceDedicatedWorkers bool `protobuf:"varint,2,opt,name=force_dedicated_workers,json=forceDedicatedWorkers,proto3" json:"forceDedicatedWorkers,omitempty"`
	// contains filtered or unexported fields
}

QuickJSConfig is the QuickJS WebWorker PluginHost controller configuration.

func NewQuickJSConfig

func NewQuickJSConfig(webRuntimeID string) *QuickJSConfig

NewQuickJSConfig constructs a new QuickJS controller config.

func (*QuickJSConfig) CloneMessageVT

func (m *QuickJSConfig) CloneMessageVT() protobuf_go_lite.CloneMessage

func (*QuickJSConfig) CloneVT

func (m *QuickJSConfig) CloneVT() *QuickJSConfig

func (*QuickJSConfig) EqualMessageVT

func (this *QuickJSConfig) EqualMessageVT(thatMsg any) bool

func (*QuickJSConfig) EqualVT

func (this *QuickJSConfig) EqualVT(that *QuickJSConfig) bool

func (*QuickJSConfig) EqualsConfig

func (c *QuickJSConfig) EqualsConfig(other config.Config) bool

EqualsConfig checks if the config is equal to another.

func (*QuickJSConfig) GetConfigID

func (c *QuickJSConfig) GetConfigID() string

GetConfigID returns the unique string for this configuration type.

func (*QuickJSConfig) GetForceDedicatedWorkers

func (x *QuickJSConfig) GetForceDedicatedWorkers() bool

func (*QuickJSConfig) GetWebRuntimeId

func (x *QuickJSConfig) GetWebRuntimeId() string

func (*QuickJSConfig) MarshalJSON

func (x *QuickJSConfig) MarshalJSON() ([]byte, error)

MarshalJSON marshals the QuickJSConfig to JSON.

func (*QuickJSConfig) MarshalProtoJSON

func (x *QuickJSConfig) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the QuickJSConfig message to JSON.

func (*QuickJSConfig) MarshalProtoText

func (x *QuickJSConfig) MarshalProtoText() string

func (*QuickJSConfig) MarshalToSizedBufferVT

func (m *QuickJSConfig) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*QuickJSConfig) MarshalToVT

func (m *QuickJSConfig) MarshalToVT(dAtA []byte) (int, error)

func (*QuickJSConfig) MarshalVT

func (m *QuickJSConfig) MarshalVT() (dAtA []byte, err error)

func (*QuickJSConfig) ProtoMessage

func (*QuickJSConfig) ProtoMessage()

func (*QuickJSConfig) Reset

func (x *QuickJSConfig) Reset()

func (*QuickJSConfig) SizeVT

func (m *QuickJSConfig) SizeVT() (n int)

func (*QuickJSConfig) String

func (x *QuickJSConfig) String() string

func (*QuickJSConfig) UnmarshalJSON

func (x *QuickJSConfig) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the QuickJSConfig from JSON.

func (*QuickJSConfig) UnmarshalProtoJSON

func (x *QuickJSConfig) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the QuickJSConfig message from JSON.

func (*QuickJSConfig) UnmarshalVT

func (m *QuickJSConfig) UnmarshalVT(dAtA []byte) error

func (*QuickJSConfig) Validate

func (c *QuickJSConfig) Validate() error

Validate validates the configuration.

type QuickJSFactory

type QuickJSFactory struct {
	// contains filtered or unexported fields
}

QuickJSFactory constructs a QuickJS plugin host.

func NewQuickJSFactory

func NewQuickJSFactory(bus bus.Bus) *QuickJSFactory

NewQuickJSFactory builds the factory.

func (*QuickJSFactory) Construct

Construct constructs the associated controller given configuration.

func (*QuickJSFactory) ConstructConfig

func (t *QuickJSFactory) ConstructConfig() config.Config

ConstructConfig constructs an instance of the controller configuration.

func (*QuickJSFactory) GetConfigID

func (t *QuickJSFactory) GetConfigID() string

GetConfigID returns the configuration ID for the controller.

func (*QuickJSFactory) GetControllerID

func (t *QuickJSFactory) GetControllerID() string

GetControllerID returns the unique ID for the controller.

func (*QuickJSFactory) GetVersion

func (t *QuickJSFactory) GetVersion() semver.Version

GetVersion returns the version of this controller.

type WebHost

type WebHost struct {
	// contains filtered or unexported fields
}

WebHost implements the plugin host with WebWorker processes.

func NewWebHost

func NewWebHost(b bus.Bus, le *logrus.Entry, webRuntimeID string, forceDedicatedWorkers bool) (*WebHost, error)

NewWebHost constructs a new WebHost.

func NewWebHostController

func NewWebHostController(
	le *logrus.Entry,
	b bus.Bus,
	c *Config,
) (*host_controller.Controller, *WebHost, error)

NewWebHostController constructs the WebHost and PluginHost controller.

func (*WebHost) DeletePlugin

func (h *WebHost) DeletePlugin(ctx context.Context, pluginID string) error

DeletePlugin clears cached plugin data for the given plugin ID.

func (*WebHost) Execute

func (h *WebHost) Execute(ctx context.Context) error

Execute is a stub as the web host does not need a global management goroutine.

func (*WebHost) ExecutePlugin

func (h *WebHost) ExecutePlugin(
	rctx context.Context,
	pluginID, instanceKey, entrypoint string,
	pluginDist, pluginAssets *unixfs.FSHandle,
	hostMux srpc.Mux,
	rpcInit plugin_host.PluginRpcInitCb,
) error

ExecutePlugin executes the plugin with the given ID. If the plugin was already initialized, existing state can be reused. The plugin should be stopped if/when the function exits. Return ErrPluginUninitialized if the plugin was not ready. Should expect to be called only once (at a time) for a plugin ID. pluginDist contains the plugin distribution files (binaries and assets).

func (*WebHost) GetPlatformId

func (h *WebHost) GetPlatformId() string

GetPlatformId returns the plugin platform ID for this host.

func (*WebHost) ListPlugins

func (h *WebHost) ListPlugins(ctx context.Context) ([]string, error)

ListPlugins lists the set of initialized plugins.

type WebQuickJSHost

type WebQuickJSHost struct {
	// contains filtered or unexported fields
}

WebQuickJSHost implements the plugin host with QuickJS WASI in browser SharedWorkers. This runs JS plugins (platform "js") in a sandboxed QuickJS environment.

func NewWebQuickJSHost

func NewWebQuickJSHost(b bus.Bus, le *logrus.Entry, webRuntimeID string, forceDedicatedWorkers bool) (*WebQuickJSHost, error)

NewWebQuickJSHost constructs a new WebQuickJSHost.

func NewWebQuickJSHostController

func NewWebQuickJSHostController(
	le *logrus.Entry,
	b bus.Bus,
	c *QuickJSConfig,
) (*host_controller.Controller, *WebQuickJSHost, error)

NewWebQuickJSHostController constructs the WebQuickJSHost and PluginHost controller.

func (*WebQuickJSHost) DeletePlugin

func (h *WebQuickJSHost) DeletePlugin(ctx context.Context, pluginID string) error

DeletePlugin clears cached plugin data for the given plugin ID.

func (*WebQuickJSHost) Execute

func (h *WebQuickJSHost) Execute(ctx context.Context) error

Execute is a stub as the web host does not need a global management goroutine.

func (*WebQuickJSHost) ExecutePlugin

func (h *WebQuickJSHost) ExecutePlugin(
	rctx context.Context,
	pluginID, instanceKey, entrypoint string,
	pluginDist, pluginAssets *unixfs.FSHandle,
	hostMux srpc.Mux,
	rpcInit plugin_host.PluginRpcInitCb,
) error

ExecutePlugin executes the plugin with the given ID. Very similar to WebHost.ExecutePlugin but uses WorkerType_SAB for blocking WASI I/O.

func (*WebQuickJSHost) GetPlatformId

func (h *WebQuickJSHost) GetPlatformId() string

GetPlatformId returns the plugin platform ID for this host.

func (*WebQuickJSHost) ListPlugins

func (h *WebQuickJSHost) ListPlugins(ctx context.Context) ([]string, error)

ListPlugins lists the set of initialized plugins.

Jump to