Documentation
¶
Index ¶
- type StorageController
- func (c *StorageController) Close() error
- func (c *StorageController) Execute(ctx context.Context) error
- func (c *StorageController) GetControllerInfo() *controller.Info
- func (c *StorageController) GetStorage() []storage.Storage
- func (c *StorageController) HandleDirective(ctx context.Context, di directive.Instance) ([]directive.Resolver, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StorageController ¶
type StorageController struct {
// contains filtered or unexported fields
}
StorageController is the bldr storage controller.
func BuildStorageController ¶
func BuildStorageController(storageId string, storage []storage.Storage, info *controller.Info) *StorageController
BuildStorageController builds a new storage controller.
func (*StorageController) Close ¶
func (c *StorageController) Close() error
Close releases any resources used by the controller.
func (*StorageController) Execute ¶
func (c *StorageController) Execute(ctx context.Context) error
Execute executes the controller goroutine.
func (*StorageController) GetControllerInfo ¶
func (c *StorageController) GetControllerInfo() *controller.Info
GetControllerInfo returns information about the controller.
func (*StorageController) GetStorage ¶
func (c *StorageController) GetStorage() []storage.Storage
GetStorage returns the Storage objects.
func (*StorageController) HandleDirective ¶
func (c *StorageController) HandleDirective(ctx context.Context, di directive.Instance) ([]directive.Resolver, error)
HandleDirective asks if the handler can resolve the directive. If it can, it returns resolver(s). If not, returns nil. It is safe to add a reference to the directive during this call. The passed context is canceled when the directive instance expires. NOTE: the passed context is not canceled when the handler is removed.
Click to show internal directories.
Click to hide internal directories.