account_settings

package
v0.51.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const BindingPurpose = "account-settings"

BindingPurpose is the logical account-settings binding purpose.

const BodyType = "account-settings"

BodyType is the SharedObjectMeta body_type for account settings SOs.

Variables

This section is empty.

Functions

func NewSharedObjectMeta

func NewSharedObjectMeta() *sobject.SharedObjectMeta

NewSharedObjectMeta returns the SharedObjectMeta for an account settings SO.

func ProcessAccountSettingsOps

func ProcessAccountSettingsOps(
	ctx context.Context,
	snap sobject.SharedObjectStateSnapshot,
	currentStateData []byte,
	ops []*sobject.SOOperationInner,
) (*[]byte, []*sobject.SOOperationResult, error)

ProcessAccountSettingsOps is a ProcessOpsFunc that applies AccountSettingsOp operations to AccountSettings state data.

Types

type AccountSettings

type AccountSettings struct {

	// DisplayName is the user-visible name for the local provider account.
	DisplayName string `protobuf:"bytes,1,opt,name=display_name,json=displayName,proto3" json:"displayName,omitempty"`
	// PairedDevices is the list of paired devices for this account.
	PairedDevices []*PairedDevice `protobuf:"bytes,2,rep,name=paired_devices,json=pairedDevices,proto3" json:"pairedDevices,omitempty"`
	// EntityKeypairs is the list of entity keypairs for authentication.
	// Synced between devices via the SharedObject.
	EntityKeypairs []*session.EntityKeypair `protobuf:"bytes,3,rep,name=entity_keypairs,json=entityKeypairs,proto3" json:"entityKeypairs,omitempty"`
	// SessionPresentations is the mirrored private presentation metadata keyed
	// by session peer ID for both local and cloud sessions.
	SessionPresentations []*SessionPresentation `protobuf:"bytes,4,rep,name=session_presentations,json=sessionPresentations,proto3" json:"sessionPresentations,omitempty"`
	// contains filtered or unexported fields
}

AccountSettings is the root state data for account settings SharedObjects. Stored as SORootInner.StateData.

func (*AccountSettings) CloneMessageVT

func (m *AccountSettings) CloneMessageVT() protobuf_go_lite.CloneMessage

func (*AccountSettings) CloneVT

func (m *AccountSettings) CloneVT() *AccountSettings

func (*AccountSettings) EqualMessageVT

func (this *AccountSettings) EqualMessageVT(thatMsg any) bool

func (*AccountSettings) EqualVT

func (this *AccountSettings) EqualVT(that *AccountSettings) bool

func (*AccountSettings) GetDisplayName

func (x *AccountSettings) GetDisplayName() string

func (*AccountSettings) GetEntityKeypairs

func (x *AccountSettings) GetEntityKeypairs() []*session.EntityKeypair

func (*AccountSettings) GetPairedDevices

func (x *AccountSettings) GetPairedDevices() []*PairedDevice

func (*AccountSettings) GetSessionPresentations

func (x *AccountSettings) GetSessionPresentations() []*SessionPresentation

func (*AccountSettings) MarshalJSON

func (x *AccountSettings) MarshalJSON() ([]byte, error)

MarshalJSON marshals the AccountSettings to JSON.

func (*AccountSettings) MarshalProtoJSON

func (x *AccountSettings) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the AccountSettings message to JSON.

func (*AccountSettings) MarshalProtoText

func (x *AccountSettings) MarshalProtoText() string

func (*AccountSettings) MarshalToSizedBufferVT

func (m *AccountSettings) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettings) MarshalToVT

func (m *AccountSettings) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettings) MarshalVT

func (m *AccountSettings) MarshalVT() (dAtA []byte, err error)

func (*AccountSettings) ProtoMessage

func (*AccountSettings) ProtoMessage()

func (*AccountSettings) Reset

func (x *AccountSettings) Reset()

func (*AccountSettings) SizeVT

func (m *AccountSettings) SizeVT() (n int)

func (*AccountSettings) String

func (x *AccountSettings) String() string

func (*AccountSettings) UnmarshalJSON

func (x *AccountSettings) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the AccountSettings from JSON.

func (*AccountSettings) UnmarshalProtoJSON

func (x *AccountSettings) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the AccountSettings message from JSON.

func (*AccountSettings) UnmarshalVT

func (m *AccountSettings) UnmarshalVT(dAtA []byte) error

type AccountSettingsOp

type AccountSettingsOp struct {

	// Types that are assignable to Op:
	//
	//	*AccountSettingsOp_UpdateDisplayName
	//	*AccountSettingsOp_AddPairedDevice
	//	*AccountSettingsOp_RemovePairedDevice
	//	*AccountSettingsOp_AddEntityKeypair
	//	*AccountSettingsOp_RemoveEntityKeypair
	//	*AccountSettingsOp_UpsertSessionPresentation
	//	*AccountSettingsOp_RemoveSessionPresentation
	Op isAccountSettingsOp_Op `protobuf_oneof:"op"`
	// contains filtered or unexported fields
}

AccountSettingsOp is an operation on the account settings SharedObject. Stored as SOOperationInner.OpData.

func (*AccountSettingsOp) CloneMessageVT

func (m *AccountSettingsOp) CloneMessageVT() protobuf_go_lite.CloneMessage

func (*AccountSettingsOp) CloneVT

func (m *AccountSettingsOp) CloneVT() *AccountSettingsOp

func (*AccountSettingsOp) EqualMessageVT

func (this *AccountSettingsOp) EqualMessageVT(thatMsg any) bool

func (*AccountSettingsOp) EqualVT

func (this *AccountSettingsOp) EqualVT(that *AccountSettingsOp) bool

func (*AccountSettingsOp) GetAddEntityKeypair

func (x *AccountSettingsOp) GetAddEntityKeypair() *session.EntityKeypair

func (*AccountSettingsOp) GetAddPairedDevice

func (x *AccountSettingsOp) GetAddPairedDevice() *PairedDevice

func (*AccountSettingsOp) GetOp

func (m *AccountSettingsOp) GetOp() isAccountSettingsOp_Op

func (*AccountSettingsOp) GetRemoveEntityKeypair

func (x *AccountSettingsOp) GetRemoveEntityKeypair() *RemoveEntityKeypairOp

func (*AccountSettingsOp) GetRemovePairedDevice

func (x *AccountSettingsOp) GetRemovePairedDevice() *RemovePairedDeviceOp

func (*AccountSettingsOp) GetRemoveSessionPresentation

func (x *AccountSettingsOp) GetRemoveSessionPresentation() *RemoveSessionPresentationOp

func (*AccountSettingsOp) GetUpdateDisplayName

func (x *AccountSettingsOp) GetUpdateDisplayName() *UpdateDisplayNameOp

func (*AccountSettingsOp) GetUpsertSessionPresentation

func (x *AccountSettingsOp) GetUpsertSessionPresentation() *SessionPresentation

func (*AccountSettingsOp) MarshalJSON

func (x *AccountSettingsOp) MarshalJSON() ([]byte, error)

MarshalJSON marshals the AccountSettingsOp to JSON.

func (*AccountSettingsOp) MarshalProtoJSON

func (x *AccountSettingsOp) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the AccountSettingsOp message to JSON.

func (*AccountSettingsOp) MarshalProtoText

func (x *AccountSettingsOp) MarshalProtoText() string

func (*AccountSettingsOp) MarshalToSizedBufferVT

func (m *AccountSettingsOp) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettingsOp) MarshalToVT

func (m *AccountSettingsOp) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettingsOp) MarshalVT

func (m *AccountSettingsOp) MarshalVT() (dAtA []byte, err error)

func (*AccountSettingsOp) ProtoMessage

func (*AccountSettingsOp) ProtoMessage()

func (*AccountSettingsOp) Reset

func (x *AccountSettingsOp) Reset()

func (*AccountSettingsOp) SizeVT

func (m *AccountSettingsOp) SizeVT() (n int)

func (*AccountSettingsOp) String

func (x *AccountSettingsOp) String() string

func (*AccountSettingsOp) UnmarshalJSON

func (x *AccountSettingsOp) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the AccountSettingsOp from JSON.

func (*AccountSettingsOp) UnmarshalProtoJSON

func (x *AccountSettingsOp) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the AccountSettingsOp message from JSON.

func (*AccountSettingsOp) UnmarshalVT

func (m *AccountSettingsOp) UnmarshalVT(dAtA []byte) error

type AccountSettingsOp_AddEntityKeypair

type AccountSettingsOp_AddEntityKeypair struct {
	// AddEntityKeypair adds an entity keypair. Deduplicates by peer_id.
	AddEntityKeypair *session.EntityKeypair `protobuf:"bytes,4,opt,name=add_entity_keypair,json=addEntityKeypair,proto3,oneof"`
}

func (*AccountSettingsOp_AddEntityKeypair) CloneOneofVT

func (m *AccountSettingsOp_AddEntityKeypair) CloneOneofVT() isAccountSettingsOp_Op

func (*AccountSettingsOp_AddEntityKeypair) CloneVT

func (*AccountSettingsOp_AddEntityKeypair) EqualVT

func (this *AccountSettingsOp_AddEntityKeypair) EqualVT(thatIface isAccountSettingsOp_Op) bool

func (*AccountSettingsOp_AddEntityKeypair) MarshalToSizedBufferVT

func (m *AccountSettingsOp_AddEntityKeypair) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_AddEntityKeypair) MarshalToVT

func (m *AccountSettingsOp_AddEntityKeypair) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_AddEntityKeypair) SizeVT

func (m *AccountSettingsOp_AddEntityKeypair) SizeVT() (n int)

type AccountSettingsOp_AddPairedDevice

type AccountSettingsOp_AddPairedDevice struct {
	// AddPairedDevice adds a paired device.
	AddPairedDevice *PairedDevice `protobuf:"bytes,2,opt,name=add_paired_device,json=addPairedDevice,proto3,oneof"`
}

func (*AccountSettingsOp_AddPairedDevice) CloneOneofVT

func (m *AccountSettingsOp_AddPairedDevice) CloneOneofVT() isAccountSettingsOp_Op

func (*AccountSettingsOp_AddPairedDevice) CloneVT

func (*AccountSettingsOp_AddPairedDevice) EqualVT

func (this *AccountSettingsOp_AddPairedDevice) EqualVT(thatIface isAccountSettingsOp_Op) bool

func (*AccountSettingsOp_AddPairedDevice) MarshalToSizedBufferVT

func (m *AccountSettingsOp_AddPairedDevice) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_AddPairedDevice) MarshalToVT

func (m *AccountSettingsOp_AddPairedDevice) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_AddPairedDevice) SizeVT

func (m *AccountSettingsOp_AddPairedDevice) SizeVT() (n int)

type AccountSettingsOp_RemoveEntityKeypair

type AccountSettingsOp_RemoveEntityKeypair struct {
	// RemoveEntityKeypair removes an entity keypair by peer_id.
	RemoveEntityKeypair *RemoveEntityKeypairOp `protobuf:"bytes,5,opt,name=remove_entity_keypair,json=removeEntityKeypair,proto3,oneof"`
}

func (*AccountSettingsOp_RemoveEntityKeypair) CloneOneofVT

func (m *AccountSettingsOp_RemoveEntityKeypair) CloneOneofVT() isAccountSettingsOp_Op

func (*AccountSettingsOp_RemoveEntityKeypair) CloneVT

func (*AccountSettingsOp_RemoveEntityKeypair) EqualVT

func (this *AccountSettingsOp_RemoveEntityKeypair) EqualVT(thatIface isAccountSettingsOp_Op) bool

func (*AccountSettingsOp_RemoveEntityKeypair) MarshalToSizedBufferVT

func (m *AccountSettingsOp_RemoveEntityKeypair) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_RemoveEntityKeypair) MarshalToVT

func (m *AccountSettingsOp_RemoveEntityKeypair) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_RemoveEntityKeypair) SizeVT

type AccountSettingsOp_RemovePairedDevice

type AccountSettingsOp_RemovePairedDevice struct {
	// RemovePairedDevice removes a paired device by peer_id.
	RemovePairedDevice *RemovePairedDeviceOp `protobuf:"bytes,3,opt,name=remove_paired_device,json=removePairedDevice,proto3,oneof"`
}

func (*AccountSettingsOp_RemovePairedDevice) CloneOneofVT

func (m *AccountSettingsOp_RemovePairedDevice) CloneOneofVT() isAccountSettingsOp_Op

func (*AccountSettingsOp_RemovePairedDevice) CloneVT

func (*AccountSettingsOp_RemovePairedDevice) EqualVT

func (this *AccountSettingsOp_RemovePairedDevice) EqualVT(thatIface isAccountSettingsOp_Op) bool

func (*AccountSettingsOp_RemovePairedDevice) MarshalToSizedBufferVT

func (m *AccountSettingsOp_RemovePairedDevice) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_RemovePairedDevice) MarshalToVT

func (m *AccountSettingsOp_RemovePairedDevice) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_RemovePairedDevice) SizeVT

func (m *AccountSettingsOp_RemovePairedDevice) SizeVT() (n int)

type AccountSettingsOp_RemoveSessionPresentation

type AccountSettingsOp_RemoveSessionPresentation struct {
	// RemoveSessionPresentation removes a session presentation by peer_id.
	RemoveSessionPresentation *RemoveSessionPresentationOp `protobuf:"bytes,7,opt,name=remove_session_presentation,json=removeSessionPresentation,proto3,oneof"`
}

func (*AccountSettingsOp_RemoveSessionPresentation) CloneOneofVT

func (m *AccountSettingsOp_RemoveSessionPresentation) CloneOneofVT() isAccountSettingsOp_Op

func (*AccountSettingsOp_RemoveSessionPresentation) CloneVT

func (*AccountSettingsOp_RemoveSessionPresentation) EqualVT

func (this *AccountSettingsOp_RemoveSessionPresentation) EqualVT(thatIface isAccountSettingsOp_Op) bool

func (*AccountSettingsOp_RemoveSessionPresentation) MarshalToSizedBufferVT

func (m *AccountSettingsOp_RemoveSessionPresentation) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_RemoveSessionPresentation) MarshalToVT

func (m *AccountSettingsOp_RemoveSessionPresentation) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_RemoveSessionPresentation) SizeVT

type AccountSettingsOp_UpdateDisplayName

type AccountSettingsOp_UpdateDisplayName struct {
	// UpdateDisplayName changes the local provider account display name.
	UpdateDisplayName *UpdateDisplayNameOp `protobuf:"bytes,1,opt,name=update_display_name,json=updateDisplayName,proto3,oneof"`
}

func (*AccountSettingsOp_UpdateDisplayName) CloneOneofVT

func (m *AccountSettingsOp_UpdateDisplayName) CloneOneofVT() isAccountSettingsOp_Op

func (*AccountSettingsOp_UpdateDisplayName) CloneVT

func (*AccountSettingsOp_UpdateDisplayName) EqualVT

func (this *AccountSettingsOp_UpdateDisplayName) EqualVT(thatIface isAccountSettingsOp_Op) bool

func (*AccountSettingsOp_UpdateDisplayName) MarshalToSizedBufferVT

func (m *AccountSettingsOp_UpdateDisplayName) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_UpdateDisplayName) MarshalToVT

func (m *AccountSettingsOp_UpdateDisplayName) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_UpdateDisplayName) SizeVT

func (m *AccountSettingsOp_UpdateDisplayName) SizeVT() (n int)

type AccountSettingsOp_UpsertSessionPresentation

type AccountSettingsOp_UpsertSessionPresentation struct {
	// UpsertSessionPresentation adds or replaces a session presentation row.
	UpsertSessionPresentation *SessionPresentation `protobuf:"bytes,6,opt,name=upsert_session_presentation,json=upsertSessionPresentation,proto3,oneof"`
}

func (*AccountSettingsOp_UpsertSessionPresentation) CloneOneofVT

func (m *AccountSettingsOp_UpsertSessionPresentation) CloneOneofVT() isAccountSettingsOp_Op

func (*AccountSettingsOp_UpsertSessionPresentation) CloneVT

func (*AccountSettingsOp_UpsertSessionPresentation) EqualVT

func (this *AccountSettingsOp_UpsertSessionPresentation) EqualVT(thatIface isAccountSettingsOp_Op) bool

func (*AccountSettingsOp_UpsertSessionPresentation) MarshalToSizedBufferVT

func (m *AccountSettingsOp_UpsertSessionPresentation) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_UpsertSessionPresentation) MarshalToVT

func (m *AccountSettingsOp_UpsertSessionPresentation) MarshalToVT(dAtA []byte) (int, error)

func (*AccountSettingsOp_UpsertSessionPresentation) SizeVT

type PairedDevice

type PairedDevice struct {

	// PeerId is the base58 string representation of the paired device's peer ID.
	PeerId string `protobuf:"bytes,1,opt,name=peer_id,json=peerId,proto3" json:"peerId,omitempty"`
	// DisplayName is a human-readable name for the device.
	DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"displayName,omitempty"`
	// PairedAt is the unix timestamp (seconds) when the device was paired.
	PairedAt int64 `protobuf:"varint,3,opt,name=paired_at,json=pairedAt,proto3" json:"pairedAt,omitempty"`
	// contains filtered or unexported fields
}

PairedDevice is a device that has been paired with this account via P2P.

func (*PairedDevice) CloneMessageVT

func (m *PairedDevice) CloneMessageVT() protobuf_go_lite.CloneMessage

func (*PairedDevice) CloneVT

func (m *PairedDevice) CloneVT() *PairedDevice

func (*PairedDevice) EqualMessageVT

func (this *PairedDevice) EqualMessageVT(thatMsg any) bool

func (*PairedDevice) EqualVT

func (this *PairedDevice) EqualVT(that *PairedDevice) bool

func (*PairedDevice) GetDisplayName

func (x *PairedDevice) GetDisplayName() string

func (*PairedDevice) GetPairedAt

func (x *PairedDevice) GetPairedAt() int64

func (*PairedDevice) GetPeerId

func (x *PairedDevice) GetPeerId() string

func (*PairedDevice) MarshalJSON

func (x *PairedDevice) MarshalJSON() ([]byte, error)

MarshalJSON marshals the PairedDevice to JSON.

func (*PairedDevice) MarshalProtoJSON

func (x *PairedDevice) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the PairedDevice message to JSON.

func (*PairedDevice) MarshalProtoText

func (x *PairedDevice) MarshalProtoText() string

func (*PairedDevice) MarshalToSizedBufferVT

func (m *PairedDevice) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*PairedDevice) MarshalToVT

func (m *PairedDevice) MarshalToVT(dAtA []byte) (int, error)

func (*PairedDevice) MarshalVT

func (m *PairedDevice) MarshalVT() (dAtA []byte, err error)

func (*PairedDevice) ProtoMessage

func (*PairedDevice) ProtoMessage()

func (*PairedDevice) Reset

func (x *PairedDevice) Reset()

func (*PairedDevice) SizeVT

func (m *PairedDevice) SizeVT() (n int)

func (*PairedDevice) String

func (x *PairedDevice) String() string

func (*PairedDevice) UnmarshalJSON

func (x *PairedDevice) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the PairedDevice from JSON.

func (*PairedDevice) UnmarshalProtoJSON

func (x *PairedDevice) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the PairedDevice message from JSON.

func (*PairedDevice) UnmarshalVT

func (m *PairedDevice) UnmarshalVT(dAtA []byte) error

type RemoveEntityKeypairOp

type RemoveEntityKeypairOp struct {

	// PeerId is the peer ID of the entity keypair to remove.
	PeerId string `protobuf:"bytes,1,opt,name=peer_id,json=peerId,proto3" json:"peerId,omitempty"`
	// contains filtered or unexported fields
}

RemoveEntityKeypairOp removes an entity keypair by peer ID.

func (*RemoveEntityKeypairOp) CloneMessageVT

func (*RemoveEntityKeypairOp) CloneVT

func (*RemoveEntityKeypairOp) EqualMessageVT

func (this *RemoveEntityKeypairOp) EqualMessageVT(thatMsg any) bool

func (*RemoveEntityKeypairOp) EqualVT

func (this *RemoveEntityKeypairOp) EqualVT(that *RemoveEntityKeypairOp) bool

func (*RemoveEntityKeypairOp) GetPeerId

func (x *RemoveEntityKeypairOp) GetPeerId() string

func (*RemoveEntityKeypairOp) MarshalJSON

func (x *RemoveEntityKeypairOp) MarshalJSON() ([]byte, error)

MarshalJSON marshals the RemoveEntityKeypairOp to JSON.

func (*RemoveEntityKeypairOp) MarshalProtoJSON

func (x *RemoveEntityKeypairOp) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the RemoveEntityKeypairOp message to JSON.

func (*RemoveEntityKeypairOp) MarshalProtoText

func (x *RemoveEntityKeypairOp) MarshalProtoText() string

func (*RemoveEntityKeypairOp) MarshalToSizedBufferVT

func (m *RemoveEntityKeypairOp) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*RemoveEntityKeypairOp) MarshalToVT

func (m *RemoveEntityKeypairOp) MarshalToVT(dAtA []byte) (int, error)

func (*RemoveEntityKeypairOp) MarshalVT

func (m *RemoveEntityKeypairOp) MarshalVT() (dAtA []byte, err error)

func (*RemoveEntityKeypairOp) ProtoMessage

func (*RemoveEntityKeypairOp) ProtoMessage()

func (*RemoveEntityKeypairOp) Reset

func (x *RemoveEntityKeypairOp) Reset()

func (*RemoveEntityKeypairOp) SizeVT

func (m *RemoveEntityKeypairOp) SizeVT() (n int)

func (*RemoveEntityKeypairOp) String

func (x *RemoveEntityKeypairOp) String() string

func (*RemoveEntityKeypairOp) UnmarshalJSON

func (x *RemoveEntityKeypairOp) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the RemoveEntityKeypairOp from JSON.

func (*RemoveEntityKeypairOp) UnmarshalProtoJSON

func (x *RemoveEntityKeypairOp) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the RemoveEntityKeypairOp message from JSON.

func (*RemoveEntityKeypairOp) UnmarshalVT

func (m *RemoveEntityKeypairOp) UnmarshalVT(dAtA []byte) error

type RemovePairedDeviceOp

type RemovePairedDeviceOp struct {

	// PeerId is the peer ID of the device to remove.
	PeerId string `protobuf:"bytes,1,opt,name=peer_id,json=peerId,proto3" json:"peerId,omitempty"`
	// contains filtered or unexported fields
}

RemovePairedDeviceOp removes a paired device by peer ID.

func (*RemovePairedDeviceOp) CloneMessageVT

func (*RemovePairedDeviceOp) CloneVT

func (*RemovePairedDeviceOp) EqualMessageVT

func (this *RemovePairedDeviceOp) EqualMessageVT(thatMsg any) bool

func (*RemovePairedDeviceOp) EqualVT

func (this *RemovePairedDeviceOp) EqualVT(that *RemovePairedDeviceOp) bool

func (*RemovePairedDeviceOp) GetPeerId

func (x *RemovePairedDeviceOp) GetPeerId() string

func (*RemovePairedDeviceOp) MarshalJSON

func (x *RemovePairedDeviceOp) MarshalJSON() ([]byte, error)

MarshalJSON marshals the RemovePairedDeviceOp to JSON.

func (*RemovePairedDeviceOp) MarshalProtoJSON

func (x *RemovePairedDeviceOp) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the RemovePairedDeviceOp message to JSON.

func (*RemovePairedDeviceOp) MarshalProtoText

func (x *RemovePairedDeviceOp) MarshalProtoText() string

func (*RemovePairedDeviceOp) MarshalToSizedBufferVT

func (m *RemovePairedDeviceOp) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*RemovePairedDeviceOp) MarshalToVT

func (m *RemovePairedDeviceOp) MarshalToVT(dAtA []byte) (int, error)

func (*RemovePairedDeviceOp) MarshalVT

func (m *RemovePairedDeviceOp) MarshalVT() (dAtA []byte, err error)

func (*RemovePairedDeviceOp) ProtoMessage

func (*RemovePairedDeviceOp) ProtoMessage()

func (*RemovePairedDeviceOp) Reset

func (x *RemovePairedDeviceOp) Reset()

func (*RemovePairedDeviceOp) SizeVT

func (m *RemovePairedDeviceOp) SizeVT() (n int)

func (*RemovePairedDeviceOp) String

func (x *RemovePairedDeviceOp) String() string

func (*RemovePairedDeviceOp) UnmarshalJSON

func (x *RemovePairedDeviceOp) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the RemovePairedDeviceOp from JSON.

func (*RemovePairedDeviceOp) UnmarshalProtoJSON

func (x *RemovePairedDeviceOp) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the RemovePairedDeviceOp message from JSON.

func (*RemovePairedDeviceOp) UnmarshalVT

func (m *RemovePairedDeviceOp) UnmarshalVT(dAtA []byte) error

type RemoveSessionPresentationOp

type RemoveSessionPresentationOp struct {

	// PeerId is the peer ID of the session metadata entry to remove.
	PeerId string `protobuf:"bytes,1,opt,name=peer_id,json=peerId,proto3" json:"peerId,omitempty"`
	// contains filtered or unexported fields
}

RemoveSessionPresentationOp removes session presentation metadata by peer ID.

func (*RemoveSessionPresentationOp) CloneMessageVT

func (*RemoveSessionPresentationOp) CloneVT

func (*RemoveSessionPresentationOp) EqualMessageVT

func (this *RemoveSessionPresentationOp) EqualMessageVT(thatMsg any) bool

func (*RemoveSessionPresentationOp) EqualVT

func (*RemoveSessionPresentationOp) GetPeerId

func (x *RemoveSessionPresentationOp) GetPeerId() string

func (*RemoveSessionPresentationOp) MarshalJSON

func (x *RemoveSessionPresentationOp) MarshalJSON() ([]byte, error)

MarshalJSON marshals the RemoveSessionPresentationOp to JSON.

func (*RemoveSessionPresentationOp) MarshalProtoJSON

func (x *RemoveSessionPresentationOp) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the RemoveSessionPresentationOp message to JSON.

func (*RemoveSessionPresentationOp) MarshalProtoText

func (x *RemoveSessionPresentationOp) MarshalProtoText() string

func (*RemoveSessionPresentationOp) MarshalToSizedBufferVT

func (m *RemoveSessionPresentationOp) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*RemoveSessionPresentationOp) MarshalToVT

func (m *RemoveSessionPresentationOp) MarshalToVT(dAtA []byte) (int, error)

func (*RemoveSessionPresentationOp) MarshalVT

func (m *RemoveSessionPresentationOp) MarshalVT() (dAtA []byte, err error)

func (*RemoveSessionPresentationOp) ProtoMessage

func (*RemoveSessionPresentationOp) ProtoMessage()

func (*RemoveSessionPresentationOp) Reset

func (x *RemoveSessionPresentationOp) Reset()

func (*RemoveSessionPresentationOp) SizeVT

func (m *RemoveSessionPresentationOp) SizeVT() (n int)

func (*RemoveSessionPresentationOp) String

func (x *RemoveSessionPresentationOp) String() string

func (*RemoveSessionPresentationOp) UnmarshalJSON

func (x *RemoveSessionPresentationOp) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the RemoveSessionPresentationOp from JSON.

func (*RemoveSessionPresentationOp) UnmarshalProtoJSON

func (x *RemoveSessionPresentationOp) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the RemoveSessionPresentationOp message from JSON.

func (*RemoveSessionPresentationOp) UnmarshalVT

func (m *RemoveSessionPresentationOp) UnmarshalVT(dAtA []byte) error

type SessionPresentation

type SessionPresentation struct {

	// PeerId is the session peer ID.
	PeerId string `protobuf:"bytes,1,opt,name=peer_id,json=peerId,proto3" json:"peerId,omitempty"`
	// Label is the primary display label for the session.
	Label string `protobuf:"bytes,2,opt,name=label,proto3" json:"label,omitempty"`
	// DeviceType identifies the broad device class ("web", "desktop", etc.).
	DeviceType string `protobuf:"bytes,3,opt,name=device_type,json=deviceType,proto3" json:"deviceType,omitempty"`
	// ClientName is the app or browser name when known.
	ClientName string `protobuf:"bytes,4,opt,name=client_name,json=clientName,proto3" json:"clientName,omitempty"`
	// Os is the operating system or platform when known.
	Os string `protobuf:"bytes,5,opt,name=os,proto3" json:"os,omitempty"`
	// Location is the observed network location when known.
	Location string `protobuf:"bytes,6,opt,name=location,proto3" json:"location,omitempty"`
	// contains filtered or unexported fields
}

SessionPresentation stores private presentation metadata for a session row.

func (*SessionPresentation) CloneMessageVT

func (*SessionPresentation) CloneVT

func (*SessionPresentation) EqualMessageVT

func (this *SessionPresentation) EqualMessageVT(thatMsg any) bool

func (*SessionPresentation) EqualVT

func (this *SessionPresentation) EqualVT(that *SessionPresentation) bool

func (*SessionPresentation) GetClientName

func (x *SessionPresentation) GetClientName() string

func (*SessionPresentation) GetDeviceType

func (x *SessionPresentation) GetDeviceType() string

func (*SessionPresentation) GetLabel

func (x *SessionPresentation) GetLabel() string

func (*SessionPresentation) GetLocation

func (x *SessionPresentation) GetLocation() string

func (*SessionPresentation) GetOs

func (x *SessionPresentation) GetOs() string

func (*SessionPresentation) GetPeerId

func (x *SessionPresentation) GetPeerId() string

func (*SessionPresentation) MarshalJSON

func (x *SessionPresentation) MarshalJSON() ([]byte, error)

MarshalJSON marshals the SessionPresentation to JSON.

func (*SessionPresentation) MarshalProtoJSON

func (x *SessionPresentation) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the SessionPresentation message to JSON.

func (*SessionPresentation) MarshalProtoText

func (x *SessionPresentation) MarshalProtoText() string

func (*SessionPresentation) MarshalToSizedBufferVT

func (m *SessionPresentation) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*SessionPresentation) MarshalToVT

func (m *SessionPresentation) MarshalToVT(dAtA []byte) (int, error)

func (*SessionPresentation) MarshalVT

func (m *SessionPresentation) MarshalVT() (dAtA []byte, err error)

func (*SessionPresentation) ProtoMessage

func (*SessionPresentation) ProtoMessage()

func (*SessionPresentation) Reset

func (x *SessionPresentation) Reset()

func (*SessionPresentation) SizeVT

func (m *SessionPresentation) SizeVT() (n int)

func (*SessionPresentation) String

func (x *SessionPresentation) String() string

func (*SessionPresentation) UnmarshalJSON

func (x *SessionPresentation) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the SessionPresentation from JSON.

func (*SessionPresentation) UnmarshalProtoJSON

func (x *SessionPresentation) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the SessionPresentation message from JSON.

func (*SessionPresentation) UnmarshalVT

func (m *SessionPresentation) UnmarshalVT(dAtA []byte) error

type UpdateDisplayNameOp

type UpdateDisplayNameOp struct {

	// DisplayName is the new display name for the account.
	DisplayName string `protobuf:"bytes,1,opt,name=display_name,json=displayName,proto3" json:"displayName,omitempty"`
	// contains filtered or unexported fields
}

UpdateDisplayNameOp changes the local provider account display name.

func (*UpdateDisplayNameOp) CloneMessageVT

func (*UpdateDisplayNameOp) CloneVT

func (*UpdateDisplayNameOp) EqualMessageVT

func (this *UpdateDisplayNameOp) EqualMessageVT(thatMsg any) bool

func (*UpdateDisplayNameOp) EqualVT

func (this *UpdateDisplayNameOp) EqualVT(that *UpdateDisplayNameOp) bool

func (*UpdateDisplayNameOp) GetDisplayName

func (x *UpdateDisplayNameOp) GetDisplayName() string

func (*UpdateDisplayNameOp) MarshalJSON

func (x *UpdateDisplayNameOp) MarshalJSON() ([]byte, error)

MarshalJSON marshals the UpdateDisplayNameOp to JSON.

func (*UpdateDisplayNameOp) MarshalProtoJSON

func (x *UpdateDisplayNameOp) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the UpdateDisplayNameOp message to JSON.

func (*UpdateDisplayNameOp) MarshalProtoText

func (x *UpdateDisplayNameOp) MarshalProtoText() string

func (*UpdateDisplayNameOp) MarshalToSizedBufferVT

func (m *UpdateDisplayNameOp) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*UpdateDisplayNameOp) MarshalToVT

func (m *UpdateDisplayNameOp) MarshalToVT(dAtA []byte) (int, error)

func (*UpdateDisplayNameOp) MarshalVT

func (m *UpdateDisplayNameOp) MarshalVT() (dAtA []byte, err error)

func (*UpdateDisplayNameOp) ProtoMessage

func (*UpdateDisplayNameOp) ProtoMessage()

func (*UpdateDisplayNameOp) Reset

func (x *UpdateDisplayNameOp) Reset()

func (*UpdateDisplayNameOp) SizeVT

func (m *UpdateDisplayNameOp) SizeVT() (n int)

func (*UpdateDisplayNameOp) String

func (x *UpdateDisplayNameOp) String() string

func (*UpdateDisplayNameOp) UnmarshalJSON

func (x *UpdateDisplayNameOp) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the UpdateDisplayNameOp from JSON.

func (*UpdateDisplayNameOp) UnmarshalProtoJSON

func (x *UpdateDisplayNameOp) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the UpdateDisplayNameOp message from JSON.

func (*UpdateDisplayNameOp) UnmarshalVT

func (m *UpdateDisplayNameOp) UnmarshalVT(dAtA []byte) error

Jump to