mysql_controller

package
v0.51.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: Apache-2.0 Imports: 23 Imported by: 0

Documentation

Index

Constants

const ConfigID = ControllerID

ConfigID is the string used to identify this config object.

const ControllerID = "hydra/sql/mysql"

ControllerID identifies the controller.

Variables

var Version = semver.MustParse("0.0.1")

Version is the API version.

Functions

This section is empty.

Types

type Config

type Config struct {

	// SqlDbId is the identifier used to look up the sql db on the bus.
	// If empty, LookupSqlDB will not be processed.
	SqlDbId string `protobuf:"bytes,1,opt,name=sql_db_id,json=sqlDbId,proto3" json:"sqlDbId,omitempty"`
	// BucketId is the bucket id to attach to for reading/writing state.
	// If set, overrides the bucket id from init_head_ref and the state.
	// If unset, the bucket id is determined from head_ref.
	BucketId string `protobuf:"bytes,2,opt,name=bucket_id,json=bucketId,proto3" json:"bucketId,omitempty"`
	// VolumeId is the volume id to attach to for writing DB state.
	// If unset, init_head_ref must be set, and the db will be read-only.
	VolumeId string `protobuf:"bytes,3,opt,name=volume_id,json=volumeId,proto3" json:"volumeId,omitempty"`
	// ObjectStoreId is the hydra object store to open to store the HEAD ref.
	// If unset, init_head_ref must be set, and the db will be read-only.
	ObjectStoreId string `protobuf:"bytes,4,opt,name=object_store_id,json=objectStoreId,proto3" json:"objectStoreId,omitempty"`
	// ObjectStorePrefix is the prefix to use for all object store ops.
	ObjectStorePrefix string `protobuf:"bytes,5,opt,name=object_store_prefix,json=objectStorePrefix,proto3" json:"objectStorePrefix,omitempty"`
	// ObjectStoreHeadKey is the key to use in the object store for HEAD ref.
	//
	// Defaults to "sql-head"
	ObjectStoreHeadKey string `protobuf:"bytes,6,opt,name=object_store_head_key,json=objectStoreHeadKey,proto3" json:"objectStoreHeadKey,omitempty"`
	// InitHeadRef is the reference to the initial HEAD state of the database.
	// If the object store is empty, uses this reference to initialize it.
	// BucketId is overridden by BucketId field if it is set.
	InitHeadRef *bucket.ObjectRef `protobuf:"bytes,7,opt,name=init_head_ref,json=initHeadRef,proto3" json:"initHeadRef,omitempty"`
	// StateTransformConf transforms the HEAD ref before storing it in storage.
	StateTransformConf *transform.Config `protobuf:"bytes,8,opt,name=state_transform_conf,json=stateTransformConf,proto3" json:"stateTransformConf,omitempty"`
	// CreateDbs is a list of database names to create (if they don't exist).
	CreateDbs []string `protobuf:"bytes,9,rep,name=create_dbs,json=createDbs,proto3" json:"createDbs,omitempty"`
	// contains filtered or unexported fields
}

Config configures a object store backed sql db controller.

func NewConfig

func NewConfig(
	sqlDBID, volumeID, bucketID, objectStoreID string,
	initHeadRef *bucket.ObjectRef,
	stateTransformConf *block_transform.Config,
) *Config

NewConfig constructs a new block world engine config.

func (*Config) CloneMessageVT

func (m *Config) CloneMessageVT() protobuf_go_lite.CloneMessage

func (*Config) CloneVT

func (m *Config) CloneVT() *Config

func (*Config) EqualMessageVT

func (this *Config) EqualMessageVT(thatMsg any) bool

func (*Config) EqualVT

func (this *Config) EqualVT(that *Config) bool

func (*Config) EqualsConfig

func (c *Config) EqualsConfig(other config.Config) bool

EqualsConfig checks if the config is equal to another.

func (*Config) GetBucketId

func (x *Config) GetBucketId() string

func (*Config) GetConfigID

func (c *Config) GetConfigID() string

GetConfigID returns the unique string for this configuration type. This string is stored with the encoded config.

func (*Config) GetCreateDbs

func (x *Config) GetCreateDbs() []string

func (*Config) GetInitHeadRef

func (x *Config) GetInitHeadRef() *bucket.ObjectRef

func (*Config) GetObjectStoreHeadKey

func (x *Config) GetObjectStoreHeadKey() string

func (*Config) GetObjectStoreId

func (x *Config) GetObjectStoreId() string

func (*Config) GetObjectStorePrefix

func (x *Config) GetObjectStorePrefix() string

func (*Config) GetSqlDbId

func (x *Config) GetSqlDbId() string

func (*Config) GetStateTransformConf

func (x *Config) GetStateTransformConf() *transform.Config

func (*Config) GetVolumeId

func (x *Config) GetVolumeId() string

func (*Config) MarshalJSON

func (x *Config) MarshalJSON() ([]byte, error)

MarshalJSON marshals the Config to JSON.

func (*Config) MarshalProtoJSON

func (x *Config) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the Config message to JSON.

func (*Config) MarshalProtoText

func (x *Config) MarshalProtoText() string

func (*Config) MarshalToSizedBufferVT

func (m *Config) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*Config) MarshalToVT

func (m *Config) MarshalToVT(dAtA []byte) (int, error)

func (*Config) MarshalVT

func (m *Config) MarshalVT() (dAtA []byte, err error)

func (*Config) ProtoMessage

func (*Config) ProtoMessage()

func (*Config) Reset

func (x *Config) Reset()

func (*Config) SizeVT

func (m *Config) SizeVT() (n int)

func (*Config) String

func (x *Config) String() string

func (*Config) UnmarshalJSON

func (x *Config) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the Config from JSON.

func (*Config) UnmarshalProtoJSON

func (x *Config) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the Config message from JSON.

func (*Config) UnmarshalVT

func (m *Config) UnmarshalVT(dAtA []byte) error

func (*Config) Validate

func (c *Config) Validate() error

Validate validates the configuration. This is a cursory validation to see if the values "look correct."

type Controller

type Controller struct {
	*hydra_sql.Controller
	// contains filtered or unexported fields
}

Controller implements the MySQL controller.

func NewController

func NewController(le *logrus.Entry, b bus.Bus, conf *Config, sfs *block_transform.StepFactorySet) (*Controller, error)

NewController constructs a new MySQL controller.

type Factory

type Factory struct {
	// contains filtered or unexported fields
}

Factory constructs a mysql engine

func NewFactory

func NewFactory(bus bus.Bus) *Factory

NewFactory builds a sql engine factory.

func (*Factory) Construct

func (t *Factory) Construct(
	ctx context.Context,
	conf config.Config,
	opts controller.ConstructOpts,
) (controller.Controller, error)

Construct constructs the associated controller given configuration.

func (*Factory) ConstructConfig

func (t *Factory) ConstructConfig() config.Config

ConstructConfig constructs an instance of the controller configuration.

func (*Factory) GetConfigID

func (t *Factory) GetConfigID() string

GetConfigID returns the configuration ID for the controller.

func (*Factory) GetControllerID

func (t *Factory) GetControllerID() string

GetControllerID returns the unique ID for the controller.

func (*Factory) GetVersion

func (t *Factory) GetVersion() semver.Version

GetVersion returns the version of this controller.

type HeadState

type HeadState struct {

	// HeadRef is the reference to the current HEAD state of the database.
	HeadRef *bucket.ObjectRef `protobuf:"bytes,1,opt,name=head_ref,json=headRef,proto3" json:"headRef,omitempty"`
	// contains filtered or unexported fields
}

HeadState contains the head state in the object storage.

func (*HeadState) CloneMessageVT

func (m *HeadState) CloneMessageVT() protobuf_go_lite.CloneMessage

func (*HeadState) CloneVT

func (m *HeadState) CloneVT() *HeadState

func (*HeadState) EqualMessageVT

func (this *HeadState) EqualMessageVT(thatMsg any) bool

func (*HeadState) EqualVT

func (this *HeadState) EqualVT(that *HeadState) bool

func (*HeadState) GetHeadRef

func (x *HeadState) GetHeadRef() *bucket.ObjectRef

func (*HeadState) MarshalJSON

func (x *HeadState) MarshalJSON() ([]byte, error)

MarshalJSON marshals the HeadState to JSON.

func (*HeadState) MarshalProtoJSON

func (x *HeadState) MarshalProtoJSON(s *json.MarshalState)

MarshalProtoJSON marshals the HeadState message to JSON.

func (*HeadState) MarshalProtoText

func (x *HeadState) MarshalProtoText() string

func (*HeadState) MarshalToSizedBufferVT

func (m *HeadState) MarshalToSizedBufferVT(dAtA []byte) (int, error)

func (*HeadState) MarshalToVT

func (m *HeadState) MarshalToVT(dAtA []byte) (int, error)

func (*HeadState) MarshalVT

func (m *HeadState) MarshalVT() (dAtA []byte, err error)

func (*HeadState) ProtoMessage

func (*HeadState) ProtoMessage()

func (*HeadState) Reset

func (x *HeadState) Reset()

func (*HeadState) SizeVT

func (m *HeadState) SizeVT() (n int)

func (*HeadState) String

func (x *HeadState) String() string

func (*HeadState) UnmarshalJSON

func (x *HeadState) UnmarshalJSON(b []byte) error

UnmarshalJSON unmarshals the HeadState from JSON.

func (*HeadState) UnmarshalProtoJSON

func (x *HeadState) UnmarshalProtoJSON(s *json.UnmarshalState)

UnmarshalProtoJSON unmarshals the HeadState message from JSON.

func (*HeadState) UnmarshalVT

func (m *HeadState) UnmarshalVT(dAtA []byte) error

Jump to