world_parent

package
v0.56.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 18, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ParentPred = quad.IRI("parent")

ParentPred is the parent predicate field.

Functions

func BuildParentQuad

func BuildParentQuad(objKey, parentKey string) quad.Quad

BuildParentQuad returns a parent quad for a key -> parent object key.

func ClearObjectParent

func ClearObjectParent(ctx context.Context, ws world.WorldState, key string) error

ClearObjectParent removes all <parent> quads from an object.

func GetObjectParent

func GetObjectParent(ctx context.Context, ws world.WorldState, key string) (string, error)

GetObjectParent returns the parent of a given object. Returns "" if the object has no parent.

func SetObjectParent

func SetObjectParent(ctx context.Context, ws world.WorldState, key, parentKey string, reset bool) error

SetObjectParent sets the parent of a given object by writing a graph quad. If reset is set, deletes any non-matching <parent> quad in the same transaction. If parentKey is empty, clears the parent.

Types

This section is empty.

Jump to