Documentation
¶
Index ¶
- Constants
- func NewSRPCDeployServiceHandler(impl SRPCDeployServiceServer, serviceID string) srpc.Handler
- func SRPCRegisterDeployService(mux srpc.Mux, impl SRPCDeployServiceServer) error
- type BlockRequest
- func (m *BlockRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *BlockRequest) CloneVT() *BlockRequest
- func (this *BlockRequest) EqualMessageVT(thatMsg any) bool
- func (this *BlockRequest) EqualVT(that *BlockRequest) bool
- func (x *BlockRequest) GetRef() *block.BlockRef
- func (x *BlockRequest) MarshalJSON() ([]byte, error)
- func (x *BlockRequest) MarshalProtoJSON(s *json.MarshalState)
- func (x *BlockRequest) MarshalProtoText() string
- func (m *BlockRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *BlockRequest) MarshalToVT(dAtA []byte) (int, error)
- func (m *BlockRequest) MarshalVT() (dAtA []byte, err error)
- func (*BlockRequest) ProtoMessage()
- func (x *BlockRequest) Reset()
- func (m *BlockRequest) SizeVT() (n int)
- func (x *BlockRequest) String() string
- func (x *BlockRequest) UnmarshalJSON(b []byte) error
- func (x *BlockRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *BlockRequest) UnmarshalVT(dAtA []byte) error
- type BlockResponse
- func (m *BlockResponse) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *BlockResponse) CloneVT() *BlockResponse
- func (this *BlockResponse) EqualMessageVT(thatMsg any) bool
- func (this *BlockResponse) EqualVT(that *BlockResponse) bool
- func (x *BlockResponse) GetData() []byte
- func (x *BlockResponse) GetNotFound() bool
- func (x *BlockResponse) GetRef() *block.BlockRef
- func (x *BlockResponse) MarshalJSON() ([]byte, error)
- func (x *BlockResponse) MarshalProtoJSON(s *json.MarshalState)
- func (x *BlockResponse) MarshalProtoText() string
- func (m *BlockResponse) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *BlockResponse) MarshalToVT(dAtA []byte) (int, error)
- func (m *BlockResponse) MarshalVT() (dAtA []byte, err error)
- func (*BlockResponse) ProtoMessage()
- func (x *BlockResponse) Reset()
- func (m *BlockResponse) SizeVT() (n int)
- func (x *BlockResponse) String() string
- func (x *BlockResponse) UnmarshalJSON(b []byte) error
- func (x *BlockResponse) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *BlockResponse) UnmarshalVT(dAtA []byte) error
- type DeployManifestMessage
- func (m *DeployManifestMessage) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *DeployManifestMessage) CloneVT() *DeployManifestMessage
- func (this *DeployManifestMessage) EqualMessageVT(thatMsg any) bool
- func (this *DeployManifestMessage) EqualVT(that *DeployManifestMessage) bool
- func (x *DeployManifestMessage) GetBlockRequest() *BlockRequest
- func (x *DeployManifestMessage) GetBlockResponse() *BlockResponse
- func (m *DeployManifestMessage) GetBody() isDeployManifestMessage_Body
- func (x *DeployManifestMessage) GetRequest() *DeployManifestRequest
- func (x *DeployManifestMessage) GetResult() *DeployManifestResult
- func (x *DeployManifestMessage) MarshalJSON() ([]byte, error)
- func (x *DeployManifestMessage) MarshalProtoJSON(s *json.MarshalState)
- func (x *DeployManifestMessage) MarshalProtoText() string
- func (m *DeployManifestMessage) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage) MarshalToVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage) MarshalVT() (dAtA []byte, err error)
- func (*DeployManifestMessage) ProtoMessage()
- func (x *DeployManifestMessage) Reset()
- func (m *DeployManifestMessage) SizeVT() (n int)
- func (x *DeployManifestMessage) String() string
- func (x *DeployManifestMessage) UnmarshalJSON(b []byte) error
- func (x *DeployManifestMessage) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *DeployManifestMessage) UnmarshalVT(dAtA []byte) error
- type DeployManifestMessage_BlockRequest
- func (m *DeployManifestMessage_BlockRequest) CloneOneofVT() isDeployManifestMessage_Body
- func (m *DeployManifestMessage_BlockRequest) CloneVT() *DeployManifestMessage_BlockRequest
- func (this *DeployManifestMessage_BlockRequest) EqualVT(thatIface isDeployManifestMessage_Body) bool
- func (m *DeployManifestMessage_BlockRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage_BlockRequest) MarshalToVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage_BlockRequest) SizeVT() (n int)
- type DeployManifestMessage_BlockResponse
- func (m *DeployManifestMessage_BlockResponse) CloneOneofVT() isDeployManifestMessage_Body
- func (m *DeployManifestMessage_BlockResponse) CloneVT() *DeployManifestMessage_BlockResponse
- func (this *DeployManifestMessage_BlockResponse) EqualVT(thatIface isDeployManifestMessage_Body) bool
- func (m *DeployManifestMessage_BlockResponse) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage_BlockResponse) MarshalToVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage_BlockResponse) SizeVT() (n int)
- type DeployManifestMessage_Request
- func (m *DeployManifestMessage_Request) CloneOneofVT() isDeployManifestMessage_Body
- func (m *DeployManifestMessage_Request) CloneVT() *DeployManifestMessage_Request
- func (this *DeployManifestMessage_Request) EqualVT(thatIface isDeployManifestMessage_Body) bool
- func (m *DeployManifestMessage_Request) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage_Request) MarshalToVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage_Request) SizeVT() (n int)
- type DeployManifestMessage_Result
- func (m *DeployManifestMessage_Result) CloneOneofVT() isDeployManifestMessage_Body
- func (m *DeployManifestMessage_Result) CloneVT() *DeployManifestMessage_Result
- func (this *DeployManifestMessage_Result) EqualVT(thatIface isDeployManifestMessage_Body) bool
- func (m *DeployManifestMessage_Result) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage_Result) MarshalToVT(dAtA []byte) (int, error)
- func (m *DeployManifestMessage_Result) SizeVT() (n int)
- type DeployManifestRequest
- func (m *DeployManifestRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *DeployManifestRequest) CloneVT() *DeployManifestRequest
- func (this *DeployManifestRequest) EqualMessageVT(thatMsg any) bool
- func (this *DeployManifestRequest) EqualVT(that *DeployManifestRequest) bool
- func (x *DeployManifestRequest) GetManifestId() string
- func (x *DeployManifestRequest) GetManifestRef() *bucket.ObjectRef
- func (x *DeployManifestRequest) GetObjectKey() string
- func (x *DeployManifestRequest) GetSpaceId() string
- func (x *DeployManifestRequest) MarshalJSON() ([]byte, error)
- func (x *DeployManifestRequest) MarshalProtoJSON(s *json.MarshalState)
- func (x *DeployManifestRequest) MarshalProtoText() string
- func (m *DeployManifestRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *DeployManifestRequest) MarshalToVT(dAtA []byte) (int, error)
- func (m *DeployManifestRequest) MarshalVT() (dAtA []byte, err error)
- func (*DeployManifestRequest) ProtoMessage()
- func (x *DeployManifestRequest) Reset()
- func (m *DeployManifestRequest) SizeVT() (n int)
- func (x *DeployManifestRequest) String() string
- func (x *DeployManifestRequest) UnmarshalJSON(b []byte) error
- func (x *DeployManifestRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *DeployManifestRequest) UnmarshalVT(dAtA []byte) error
- type DeployManifestResult
- func (m *DeployManifestResult) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *DeployManifestResult) CloneVT() *DeployManifestResult
- func (this *DeployManifestResult) EqualMessageVT(thatMsg any) bool
- func (this *DeployManifestResult) EqualVT(that *DeployManifestResult) bool
- func (x *DeployManifestResult) GetError() string
- func (x *DeployManifestResult) MarshalJSON() ([]byte, error)
- func (x *DeployManifestResult) MarshalProtoJSON(s *json.MarshalState)
- func (x *DeployManifestResult) MarshalProtoText() string
- func (m *DeployManifestResult) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *DeployManifestResult) MarshalToVT(dAtA []byte) (int, error)
- func (m *DeployManifestResult) MarshalVT() (dAtA []byte, err error)
- func (*DeployManifestResult) ProtoMessage()
- func (x *DeployManifestResult) Reset()
- func (m *DeployManifestResult) SizeVT() (n int)
- func (x *DeployManifestResult) String() string
- func (x *DeployManifestResult) UnmarshalJSON(b []byte) error
- func (x *DeployManifestResult) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *DeployManifestResult) UnmarshalVT(dAtA []byte) error
- type SRPCDeployServiceClient
- type SRPCDeployServiceHandler
- func (SRPCDeployServiceHandler) GetMethodIDs() []string
- func (d *SRPCDeployServiceHandler) GetServiceID() string
- func (d *SRPCDeployServiceHandler) InvokeMethod(serviceID, methodID string, strm srpc.Stream) (bool, error)
- func (SRPCDeployServiceHandler) InvokeMethod_DeployManifest(impl SRPCDeployServiceServer, strm srpc.Stream) error
- type SRPCDeployServiceServer
- type SRPCDeployService_DeployManifestClient
- type SRPCDeployService_DeployManifestStream
Constants ¶
const SRPCDeployServiceServiceID = "s4wave.deploy.DeployService"
Variables ¶
This section is empty.
Functions ¶
func NewSRPCDeployServiceHandler ¶
func NewSRPCDeployServiceHandler(impl SRPCDeployServiceServer, serviceID string) srpc.Handler
NewSRPCDeployServiceHandler constructs a new RPC handler. serviceID: if empty, uses default: s4wave.deploy.DeployService
func SRPCRegisterDeployService ¶
func SRPCRegisterDeployService(mux srpc.Mux, impl SRPCDeployServiceServer) error
SRPCRegisterDeployService registers the implementation with the mux. Uses the default serviceID: s4wave.deploy.DeployService
Types ¶
type BlockRequest ¶
type BlockRequest struct {
// Ref is the block reference to fetch.
Ref *block.BlockRef `protobuf:"bytes,1,opt,name=ref,proto3" json:"ref,omitempty"`
// contains filtered or unexported fields
}
BlockRequest is a request from the server for a specific block.
func (*BlockRequest) CloneMessageVT ¶
func (m *BlockRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*BlockRequest) CloneVT ¶
func (m *BlockRequest) CloneVT() *BlockRequest
func (*BlockRequest) EqualMessageVT ¶
func (this *BlockRequest) EqualMessageVT(thatMsg any) bool
func (*BlockRequest) EqualVT ¶
func (this *BlockRequest) EqualVT(that *BlockRequest) bool
func (*BlockRequest) GetRef ¶
func (x *BlockRequest) GetRef() *block.BlockRef
func (*BlockRequest) MarshalJSON ¶
func (x *BlockRequest) MarshalJSON() ([]byte, error)
MarshalJSON marshals the BlockRequest to JSON.
func (*BlockRequest) MarshalProtoJSON ¶
func (x *BlockRequest) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the BlockRequest message to JSON.
func (*BlockRequest) MarshalProtoText ¶
func (x *BlockRequest) MarshalProtoText() string
func (*BlockRequest) MarshalToSizedBufferVT ¶
func (m *BlockRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*BlockRequest) MarshalToVT ¶
func (m *BlockRequest) MarshalToVT(dAtA []byte) (int, error)
func (*BlockRequest) MarshalVT ¶
func (m *BlockRequest) MarshalVT() (dAtA []byte, err error)
func (*BlockRequest) ProtoMessage ¶
func (*BlockRequest) ProtoMessage()
func (*BlockRequest) Reset ¶
func (x *BlockRequest) Reset()
func (*BlockRequest) SizeVT ¶
func (m *BlockRequest) SizeVT() (n int)
func (*BlockRequest) String ¶
func (x *BlockRequest) String() string
func (*BlockRequest) UnmarshalJSON ¶
func (x *BlockRequest) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the BlockRequest from JSON.
func (*BlockRequest) UnmarshalProtoJSON ¶
func (x *BlockRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the BlockRequest message from JSON.
func (*BlockRequest) UnmarshalVT ¶
func (m *BlockRequest) UnmarshalVT(dAtA []byte) error
type BlockResponse ¶
type BlockResponse struct {
// Ref is the block reference.
Ref *block.BlockRef `protobuf:"bytes,1,opt,name=ref,proto3" json:"ref,omitempty"`
// Data is the raw block bytes.
Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
// NotFound indicates the block was not found in the source.
NotFound bool `protobuf:"varint,3,opt,name=not_found,json=notFound,proto3" json:"notFound,omitempty"`
// contains filtered or unexported fields
}
BlockResponse is the client's response with block data.
func (*BlockResponse) CloneMessageVT ¶
func (m *BlockResponse) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*BlockResponse) CloneVT ¶
func (m *BlockResponse) CloneVT() *BlockResponse
func (*BlockResponse) EqualMessageVT ¶
func (this *BlockResponse) EqualMessageVT(thatMsg any) bool
func (*BlockResponse) EqualVT ¶
func (this *BlockResponse) EqualVT(that *BlockResponse) bool
func (*BlockResponse) GetData ¶
func (x *BlockResponse) GetData() []byte
func (*BlockResponse) GetNotFound ¶
func (x *BlockResponse) GetNotFound() bool
func (*BlockResponse) GetRef ¶
func (x *BlockResponse) GetRef() *block.BlockRef
func (*BlockResponse) MarshalJSON ¶
func (x *BlockResponse) MarshalJSON() ([]byte, error)
MarshalJSON marshals the BlockResponse to JSON.
func (*BlockResponse) MarshalProtoJSON ¶
func (x *BlockResponse) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the BlockResponse message to JSON.
func (*BlockResponse) MarshalProtoText ¶
func (x *BlockResponse) MarshalProtoText() string
func (*BlockResponse) MarshalToSizedBufferVT ¶
func (m *BlockResponse) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*BlockResponse) MarshalToVT ¶
func (m *BlockResponse) MarshalToVT(dAtA []byte) (int, error)
func (*BlockResponse) MarshalVT ¶
func (m *BlockResponse) MarshalVT() (dAtA []byte, err error)
func (*BlockResponse) ProtoMessage ¶
func (*BlockResponse) ProtoMessage()
func (*BlockResponse) Reset ¶
func (x *BlockResponse) Reset()
func (*BlockResponse) SizeVT ¶
func (m *BlockResponse) SizeVT() (n int)
func (*BlockResponse) String ¶
func (x *BlockResponse) String() string
func (*BlockResponse) UnmarshalJSON ¶
func (x *BlockResponse) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the BlockResponse from JSON.
func (*BlockResponse) UnmarshalProtoJSON ¶
func (x *BlockResponse) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the BlockResponse message from JSON.
func (*BlockResponse) UnmarshalVT ¶
func (m *BlockResponse) UnmarshalVT(dAtA []byte) error
type DeployManifestMessage ¶
type DeployManifestMessage struct {
// Types that are assignable to Body:
//
// *DeployManifestMessage_Request
// *DeployManifestMessage_BlockRequest
// *DeployManifestMessage_BlockResponse
// *DeployManifestMessage_Result
Body isDeployManifestMessage_Body `protobuf_oneof:"body"`
// contains filtered or unexported fields
}
DeployManifestMessage is the bidirectional message for manifest deployment.
func (*DeployManifestMessage) CloneMessageVT ¶
func (m *DeployManifestMessage) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*DeployManifestMessage) CloneVT ¶
func (m *DeployManifestMessage) CloneVT() *DeployManifestMessage
func (*DeployManifestMessage) EqualMessageVT ¶
func (this *DeployManifestMessage) EqualMessageVT(thatMsg any) bool
func (*DeployManifestMessage) EqualVT ¶
func (this *DeployManifestMessage) EqualVT(that *DeployManifestMessage) bool
func (*DeployManifestMessage) GetBlockRequest ¶
func (x *DeployManifestMessage) GetBlockRequest() *BlockRequest
func (*DeployManifestMessage) GetBlockResponse ¶
func (x *DeployManifestMessage) GetBlockResponse() *BlockResponse
func (*DeployManifestMessage) GetBody ¶
func (m *DeployManifestMessage) GetBody() isDeployManifestMessage_Body
func (*DeployManifestMessage) GetRequest ¶
func (x *DeployManifestMessage) GetRequest() *DeployManifestRequest
func (*DeployManifestMessage) GetResult ¶
func (x *DeployManifestMessage) GetResult() *DeployManifestResult
func (*DeployManifestMessage) MarshalJSON ¶
func (x *DeployManifestMessage) MarshalJSON() ([]byte, error)
MarshalJSON marshals the DeployManifestMessage to JSON.
func (*DeployManifestMessage) MarshalProtoJSON ¶
func (x *DeployManifestMessage) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the DeployManifestMessage message to JSON.
func (*DeployManifestMessage) MarshalProtoText ¶
func (x *DeployManifestMessage) MarshalProtoText() string
func (*DeployManifestMessage) MarshalToSizedBufferVT ¶
func (m *DeployManifestMessage) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*DeployManifestMessage) MarshalToVT ¶
func (m *DeployManifestMessage) MarshalToVT(dAtA []byte) (int, error)
func (*DeployManifestMessage) MarshalVT ¶
func (m *DeployManifestMessage) MarshalVT() (dAtA []byte, err error)
func (*DeployManifestMessage) ProtoMessage ¶
func (*DeployManifestMessage) ProtoMessage()
func (*DeployManifestMessage) Reset ¶
func (x *DeployManifestMessage) Reset()
func (*DeployManifestMessage) SizeVT ¶
func (m *DeployManifestMessage) SizeVT() (n int)
func (*DeployManifestMessage) String ¶
func (x *DeployManifestMessage) String() string
func (*DeployManifestMessage) UnmarshalJSON ¶
func (x *DeployManifestMessage) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the DeployManifestMessage from JSON.
func (*DeployManifestMessage) UnmarshalProtoJSON ¶
func (x *DeployManifestMessage) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the DeployManifestMessage message from JSON.
func (*DeployManifestMessage) UnmarshalVT ¶
func (m *DeployManifestMessage) UnmarshalVT(dAtA []byte) error
type DeployManifestMessage_BlockRequest ¶
type DeployManifestMessage_BlockRequest struct {
// BlockRequest is sent server->client to request a block.
BlockRequest *BlockRequest `protobuf:"bytes,2,opt,name=block_request,json=blockRequest,proto3,oneof"`
}
func (*DeployManifestMessage_BlockRequest) CloneOneofVT ¶
func (m *DeployManifestMessage_BlockRequest) CloneOneofVT() isDeployManifestMessage_Body
func (*DeployManifestMessage_BlockRequest) CloneVT ¶
func (m *DeployManifestMessage_BlockRequest) CloneVT() *DeployManifestMessage_BlockRequest
func (*DeployManifestMessage_BlockRequest) EqualVT ¶
func (this *DeployManifestMessage_BlockRequest) EqualVT(thatIface isDeployManifestMessage_Body) bool
func (*DeployManifestMessage_BlockRequest) MarshalToSizedBufferVT ¶
func (m *DeployManifestMessage_BlockRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*DeployManifestMessage_BlockRequest) MarshalToVT ¶
func (m *DeployManifestMessage_BlockRequest) MarshalToVT(dAtA []byte) (int, error)
func (*DeployManifestMessage_BlockRequest) SizeVT ¶
func (m *DeployManifestMessage_BlockRequest) SizeVT() (n int)
type DeployManifestMessage_BlockResponse ¶
type DeployManifestMessage_BlockResponse struct {
// BlockResponse is sent client->server with block data.
BlockResponse *BlockResponse `protobuf:"bytes,3,opt,name=block_response,json=blockResponse,proto3,oneof"`
}
func (*DeployManifestMessage_BlockResponse) CloneOneofVT ¶
func (m *DeployManifestMessage_BlockResponse) CloneOneofVT() isDeployManifestMessage_Body
func (*DeployManifestMessage_BlockResponse) CloneVT ¶
func (m *DeployManifestMessage_BlockResponse) CloneVT() *DeployManifestMessage_BlockResponse
func (*DeployManifestMessage_BlockResponse) EqualVT ¶
func (this *DeployManifestMessage_BlockResponse) EqualVT(thatIface isDeployManifestMessage_Body) bool
func (*DeployManifestMessage_BlockResponse) MarshalToSizedBufferVT ¶
func (m *DeployManifestMessage_BlockResponse) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*DeployManifestMessage_BlockResponse) MarshalToVT ¶
func (m *DeployManifestMessage_BlockResponse) MarshalToVT(dAtA []byte) (int, error)
func (*DeployManifestMessage_BlockResponse) SizeVT ¶
func (m *DeployManifestMessage_BlockResponse) SizeVT() (n int)
type DeployManifestMessage_Request ¶
type DeployManifestMessage_Request struct {
// DeployManifestRequest is sent client->server as the initial request.
Request *DeployManifestRequest `protobuf:"bytes,1,opt,name=request,proto3,oneof"`
}
func (*DeployManifestMessage_Request) CloneOneofVT ¶
func (m *DeployManifestMessage_Request) CloneOneofVT() isDeployManifestMessage_Body
func (*DeployManifestMessage_Request) CloneVT ¶
func (m *DeployManifestMessage_Request) CloneVT() *DeployManifestMessage_Request
func (*DeployManifestMessage_Request) EqualVT ¶
func (this *DeployManifestMessage_Request) EqualVT(thatIface isDeployManifestMessage_Body) bool
func (*DeployManifestMessage_Request) MarshalToSizedBufferVT ¶
func (m *DeployManifestMessage_Request) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*DeployManifestMessage_Request) MarshalToVT ¶
func (m *DeployManifestMessage_Request) MarshalToVT(dAtA []byte) (int, error)
func (*DeployManifestMessage_Request) SizeVT ¶
func (m *DeployManifestMessage_Request) SizeVT() (n int)
type DeployManifestMessage_Result ¶
type DeployManifestMessage_Result struct {
// DeployManifestResult is sent server->client when deployment completes.
Result *DeployManifestResult `protobuf:"bytes,4,opt,name=result,proto3,oneof"`
}
func (*DeployManifestMessage_Result) CloneOneofVT ¶
func (m *DeployManifestMessage_Result) CloneOneofVT() isDeployManifestMessage_Body
func (*DeployManifestMessage_Result) CloneVT ¶
func (m *DeployManifestMessage_Result) CloneVT() *DeployManifestMessage_Result
func (*DeployManifestMessage_Result) EqualVT ¶
func (this *DeployManifestMessage_Result) EqualVT(thatIface isDeployManifestMessage_Body) bool
func (*DeployManifestMessage_Result) MarshalToSizedBufferVT ¶
func (m *DeployManifestMessage_Result) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*DeployManifestMessage_Result) MarshalToVT ¶
func (m *DeployManifestMessage_Result) MarshalToVT(dAtA []byte) (int, error)
func (*DeployManifestMessage_Result) SizeVT ¶
func (m *DeployManifestMessage_Result) SizeVT() (n int)
type DeployManifestRequest ¶
type DeployManifestRequest struct {
// SpaceId is the ID of the Space to deploy to.
SpaceId string `protobuf:"bytes,1,opt,name=space_id,json=spaceId,proto3" json:"spaceId,omitempty"`
// ManifestRef is the object ref of the manifest to deploy.
// Contains the root block ref and the transform config used to encode blocks.
ManifestRef *bucket.ObjectRef `protobuf:"bytes,2,opt,name=manifest_ref,json=manifestRef,proto3" json:"manifestRef,omitempty"`
// ObjectKey is the object key to store the manifest under in the Space world.
ObjectKey string `protobuf:"bytes,3,opt,name=object_key,json=objectKey,proto3" json:"objectKey,omitempty"`
// ManifestId is the manifest identifier (e.g., "glados-core").
ManifestId string `protobuf:"bytes,4,opt,name=manifest_id,json=manifestId,proto3" json:"manifestId,omitempty"`
// contains filtered or unexported fields
}
DeployManifestRequest is the initial deployment request from the CLI.
func (*DeployManifestRequest) CloneMessageVT ¶
func (m *DeployManifestRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*DeployManifestRequest) CloneVT ¶
func (m *DeployManifestRequest) CloneVT() *DeployManifestRequest
func (*DeployManifestRequest) EqualMessageVT ¶
func (this *DeployManifestRequest) EqualMessageVT(thatMsg any) bool
func (*DeployManifestRequest) EqualVT ¶
func (this *DeployManifestRequest) EqualVT(that *DeployManifestRequest) bool
func (*DeployManifestRequest) GetManifestId ¶
func (x *DeployManifestRequest) GetManifestId() string
func (*DeployManifestRequest) GetManifestRef ¶
func (x *DeployManifestRequest) GetManifestRef() *bucket.ObjectRef
func (*DeployManifestRequest) GetObjectKey ¶
func (x *DeployManifestRequest) GetObjectKey() string
func (*DeployManifestRequest) GetSpaceId ¶
func (x *DeployManifestRequest) GetSpaceId() string
func (*DeployManifestRequest) MarshalJSON ¶
func (x *DeployManifestRequest) MarshalJSON() ([]byte, error)
MarshalJSON marshals the DeployManifestRequest to JSON.
func (*DeployManifestRequest) MarshalProtoJSON ¶
func (x *DeployManifestRequest) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the DeployManifestRequest message to JSON.
func (*DeployManifestRequest) MarshalProtoText ¶
func (x *DeployManifestRequest) MarshalProtoText() string
func (*DeployManifestRequest) MarshalToSizedBufferVT ¶
func (m *DeployManifestRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*DeployManifestRequest) MarshalToVT ¶
func (m *DeployManifestRequest) MarshalToVT(dAtA []byte) (int, error)
func (*DeployManifestRequest) MarshalVT ¶
func (m *DeployManifestRequest) MarshalVT() (dAtA []byte, err error)
func (*DeployManifestRequest) ProtoMessage ¶
func (*DeployManifestRequest) ProtoMessage()
func (*DeployManifestRequest) Reset ¶
func (x *DeployManifestRequest) Reset()
func (*DeployManifestRequest) SizeVT ¶
func (m *DeployManifestRequest) SizeVT() (n int)
func (*DeployManifestRequest) String ¶
func (x *DeployManifestRequest) String() string
func (*DeployManifestRequest) UnmarshalJSON ¶
func (x *DeployManifestRequest) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the DeployManifestRequest from JSON.
func (*DeployManifestRequest) UnmarshalProtoJSON ¶
func (x *DeployManifestRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the DeployManifestRequest message from JSON.
func (*DeployManifestRequest) UnmarshalVT ¶
func (m *DeployManifestRequest) UnmarshalVT(dAtA []byte) error
type DeployManifestResult ¶
type DeployManifestResult struct {
// Error is set if deployment failed.
Error string `protobuf:"bytes,1,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
DeployManifestResult is sent when deployment completes.
func (*DeployManifestResult) CloneMessageVT ¶
func (m *DeployManifestResult) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*DeployManifestResult) CloneVT ¶
func (m *DeployManifestResult) CloneVT() *DeployManifestResult
func (*DeployManifestResult) EqualMessageVT ¶
func (this *DeployManifestResult) EqualMessageVT(thatMsg any) bool
func (*DeployManifestResult) EqualVT ¶
func (this *DeployManifestResult) EqualVT(that *DeployManifestResult) bool
func (*DeployManifestResult) GetError ¶
func (x *DeployManifestResult) GetError() string
func (*DeployManifestResult) MarshalJSON ¶
func (x *DeployManifestResult) MarshalJSON() ([]byte, error)
MarshalJSON marshals the DeployManifestResult to JSON.
func (*DeployManifestResult) MarshalProtoJSON ¶
func (x *DeployManifestResult) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the DeployManifestResult message to JSON.
func (*DeployManifestResult) MarshalProtoText ¶
func (x *DeployManifestResult) MarshalProtoText() string
func (*DeployManifestResult) MarshalToSizedBufferVT ¶
func (m *DeployManifestResult) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*DeployManifestResult) MarshalToVT ¶
func (m *DeployManifestResult) MarshalToVT(dAtA []byte) (int, error)
func (*DeployManifestResult) MarshalVT ¶
func (m *DeployManifestResult) MarshalVT() (dAtA []byte, err error)
func (*DeployManifestResult) ProtoMessage ¶
func (*DeployManifestResult) ProtoMessage()
func (*DeployManifestResult) Reset ¶
func (x *DeployManifestResult) Reset()
func (*DeployManifestResult) SizeVT ¶
func (m *DeployManifestResult) SizeVT() (n int)
func (*DeployManifestResult) String ¶
func (x *DeployManifestResult) String() string
func (*DeployManifestResult) UnmarshalJSON ¶
func (x *DeployManifestResult) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the DeployManifestResult from JSON.
func (*DeployManifestResult) UnmarshalProtoJSON ¶
func (x *DeployManifestResult) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the DeployManifestResult message from JSON.
func (*DeployManifestResult) UnmarshalVT ¶
func (m *DeployManifestResult) UnmarshalVT(dAtA []byte) error
type SRPCDeployServiceClient ¶
type SRPCDeployServiceClient interface {
// SRPCClient returns the underlying SRPC client.
SRPCClient() srpc.Client
// DeployManifest deploys a manifest and its blocks into a Space.
// Bidirectional stream: client serves blocks, server requests them.
DeployManifest(ctx context.Context) (SRPCDeployService_DeployManifestClient, error)
}
func NewSRPCDeployServiceClient ¶
func NewSRPCDeployServiceClient(cc srpc.Client) SRPCDeployServiceClient
func NewSRPCDeployServiceClientWithServiceID ¶
func NewSRPCDeployServiceClientWithServiceID(cc srpc.Client, serviceID string) SRPCDeployServiceClient
type SRPCDeployServiceHandler ¶
type SRPCDeployServiceHandler struct {
// contains filtered or unexported fields
}
func (SRPCDeployServiceHandler) GetMethodIDs ¶
func (SRPCDeployServiceHandler) GetMethodIDs() []string
func (*SRPCDeployServiceHandler) GetServiceID ¶
func (d *SRPCDeployServiceHandler) GetServiceID() string
func (*SRPCDeployServiceHandler) InvokeMethod ¶
func (SRPCDeployServiceHandler) InvokeMethod_DeployManifest ¶
func (SRPCDeployServiceHandler) InvokeMethod_DeployManifest(impl SRPCDeployServiceServer, strm srpc.Stream) error
type SRPCDeployServiceServer ¶
type SRPCDeployServiceServer interface {
// DeployManifest deploys a manifest and its blocks into a Space.
// Bidirectional stream: client serves blocks, server requests them.
DeployManifest(SRPCDeployService_DeployManifestStream) error
}
type SRPCDeployService_DeployManifestClient ¶
type SRPCDeployService_DeployManifestClient interface {
srpc.Stream
Send(*DeployManifestMessage) error
Recv() (*DeployManifestMessage, error)
RecvTo(*DeployManifestMessage) error
}
type SRPCDeployService_DeployManifestStream ¶
type SRPCDeployService_DeployManifestStream interface {
srpc.Stream
Send(*DeployManifestMessage) error
SendAndClose(*DeployManifestMessage) error
Recv() (*DeployManifestMessage, error)
RecvTo(*DeployManifestMessage) error
}