Documentation
¶
Index ¶
- Variables
- func BuildParentQuad(objKey, parentKey string) quad.Quad
- func ClearObjectParent(ctx context.Context, ws world.WorldState, key string) error
- func GetObjectParent(ctx context.Context, ws world.WorldState, key string) (string, error)
- func SetObjectParent(ctx context.Context, ws world.WorldState, key, parentKey string, reset bool) error
Constants ¶
This section is empty.
Variables ¶
var ParentPred = quad.IRI("parent")
ParentPred is the parent predicate field.
Functions ¶
func BuildParentQuad ¶
BuildParentQuad returns a parent quad for a key -> parent object key.
func ClearObjectParent ¶
ClearObjectParent removes all <parent> quads from an object.
func GetObjectParent ¶
GetObjectParent returns the parent of a given object. Returns "" if the object has no parent.
func SetObjectParent ¶
func SetObjectParent(ctx context.Context, ws world.WorldState, key, parentKey string, reset bool) error
SetObjectParent sets the parent of a given object by writing a graph quad. If reset is set, deletes any non-matching <parent> quad in the same transaction. If parentKey is empty, clears the parent.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.