Documentation
¶
Index ¶
- Constants
- Variables
- func NewSRPCCdnResourceServiceHandler(impl SRPCCdnResourceServiceServer, serviceID string) srpc.Handler
- func SRPCRegisterCdnResourceService(mux srpc.Mux, impl SRPCCdnResourceServiceServer) error
- type CopyV86ImageToSpaceProgress
- func (m *CopyV86ImageToSpaceProgress) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *CopyV86ImageToSpaceProgress) CloneVT() *CopyV86ImageToSpaceProgress
- func (this *CopyV86ImageToSpaceProgress) EqualMessageVT(thatMsg any) bool
- func (this *CopyV86ImageToSpaceProgress) EqualVT(that *CopyV86ImageToSpaceProgress) bool
- func (x *CopyV86ImageToSpaceProgress) GetBlocksCopied() uint64
- func (x *CopyV86ImageToSpaceProgress) GetBlocksSeen() uint64
- func (x *CopyV86ImageToSpaceProgress) GetBlocksWritten() uint64
- func (x *CopyV86ImageToSpaceProgress) GetLogicalSourceBytes() uint64
- func (x *CopyV86ImageToSpaceProgress) GetStage() CopyV86ImageToSpaceStage
- func (x *CopyV86ImageToSpaceProgress) MarshalJSON() ([]byte, error)
- func (x *CopyV86ImageToSpaceProgress) MarshalProtoJSON(s *json.MarshalState)
- func (x *CopyV86ImageToSpaceProgress) MarshalProtoText() string
- func (m *CopyV86ImageToSpaceProgress) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *CopyV86ImageToSpaceProgress) MarshalToVT(dAtA []byte) (int, error)
- func (m *CopyV86ImageToSpaceProgress) MarshalVT() (dAtA []byte, err error)
- func (*CopyV86ImageToSpaceProgress) ProtoMessage()
- func (x *CopyV86ImageToSpaceProgress) Reset()
- func (m *CopyV86ImageToSpaceProgress) SizeVT() (n int)
- func (x *CopyV86ImageToSpaceProgress) String() string
- func (x *CopyV86ImageToSpaceProgress) UnmarshalJSON(b []byte) error
- func (x *CopyV86ImageToSpaceProgress) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *CopyV86ImageToSpaceProgress) UnmarshalVT(dAtA []byte) error
- type CopyV86ImageToSpaceRequest
- func (m *CopyV86ImageToSpaceRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *CopyV86ImageToSpaceRequest) CloneVT() *CopyV86ImageToSpaceRequest
- func (this *CopyV86ImageToSpaceRequest) EqualMessageVT(thatMsg any) bool
- func (this *CopyV86ImageToSpaceRequest) EqualVT(that *CopyV86ImageToSpaceRequest) bool
- func (x *CopyV86ImageToSpaceRequest) GetDstObjectKey() string
- func (x *CopyV86ImageToSpaceRequest) GetDstSpaceId() string
- func (x *CopyV86ImageToSpaceRequest) GetSessionIdx() uint32
- func (x *CopyV86ImageToSpaceRequest) GetSrcObjectKey() string
- func (x *CopyV86ImageToSpaceRequest) MarshalJSON() ([]byte, error)
- func (x *CopyV86ImageToSpaceRequest) MarshalProtoJSON(s *json.MarshalState)
- func (x *CopyV86ImageToSpaceRequest) MarshalProtoText() string
- func (m *CopyV86ImageToSpaceRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *CopyV86ImageToSpaceRequest) MarshalToVT(dAtA []byte) (int, error)
- func (m *CopyV86ImageToSpaceRequest) MarshalVT() (dAtA []byte, err error)
- func (*CopyV86ImageToSpaceRequest) ProtoMessage()
- func (x *CopyV86ImageToSpaceRequest) Reset()
- func (m *CopyV86ImageToSpaceRequest) SizeVT() (n int)
- func (x *CopyV86ImageToSpaceRequest) String() string
- func (x *CopyV86ImageToSpaceRequest) UnmarshalJSON(b []byte) error
- func (x *CopyV86ImageToSpaceRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *CopyV86ImageToSpaceRequest) UnmarshalVT(dAtA []byte) error
- type CopyV86ImageToSpaceStage
- func (x CopyV86ImageToSpaceStage) Enum() *CopyV86ImageToSpaceStage
- func (x CopyV86ImageToSpaceStage) MarshalJSON() ([]byte, error)
- func (x CopyV86ImageToSpaceStage) MarshalProtoJSON(s *json.MarshalState)
- func (x CopyV86ImageToSpaceStage) MarshalProtoText() string
- func (x CopyV86ImageToSpaceStage) MarshalText() ([]byte, error)
- func (x CopyV86ImageToSpaceStage) String() string
- func (x *CopyV86ImageToSpaceStage) UnmarshalJSON(b []byte) error
- func (x *CopyV86ImageToSpaceStage) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (x *CopyV86ImageToSpaceStage) UnmarshalText(b []byte) error
- type GetCdnSpaceIdRequest
- func (m *GetCdnSpaceIdRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *GetCdnSpaceIdRequest) CloneVT() *GetCdnSpaceIdRequest
- func (this *GetCdnSpaceIdRequest) EqualMessageVT(thatMsg any) bool
- func (this *GetCdnSpaceIdRequest) EqualVT(that *GetCdnSpaceIdRequest) bool
- func (x *GetCdnSpaceIdRequest) MarshalJSON() ([]byte, error)
- func (x *GetCdnSpaceIdRequest) MarshalProtoJSON(s *json.MarshalState)
- func (x *GetCdnSpaceIdRequest) MarshalProtoText() string
- func (m *GetCdnSpaceIdRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *GetCdnSpaceIdRequest) MarshalToVT(dAtA []byte) (int, error)
- func (m *GetCdnSpaceIdRequest) MarshalVT() (dAtA []byte, err error)
- func (*GetCdnSpaceIdRequest) ProtoMessage()
- func (x *GetCdnSpaceIdRequest) Reset()
- func (m *GetCdnSpaceIdRequest) SizeVT() (n int)
- func (x *GetCdnSpaceIdRequest) String() string
- func (x *GetCdnSpaceIdRequest) UnmarshalJSON(b []byte) error
- func (x *GetCdnSpaceIdRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *GetCdnSpaceIdRequest) UnmarshalVT(dAtA []byte) error
- type GetCdnSpaceIdResponse
- func (m *GetCdnSpaceIdResponse) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *GetCdnSpaceIdResponse) CloneVT() *GetCdnSpaceIdResponse
- func (this *GetCdnSpaceIdResponse) EqualMessageVT(thatMsg any) bool
- func (this *GetCdnSpaceIdResponse) EqualVT(that *GetCdnSpaceIdResponse) bool
- func (x *GetCdnSpaceIdResponse) GetSpaceId() string
- func (x *GetCdnSpaceIdResponse) MarshalJSON() ([]byte, error)
- func (x *GetCdnSpaceIdResponse) MarshalProtoJSON(s *json.MarshalState)
- func (x *GetCdnSpaceIdResponse) MarshalProtoText() string
- func (m *GetCdnSpaceIdResponse) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *GetCdnSpaceIdResponse) MarshalToVT(dAtA []byte) (int, error)
- func (m *GetCdnSpaceIdResponse) MarshalVT() (dAtA []byte, err error)
- func (*GetCdnSpaceIdResponse) ProtoMessage()
- func (x *GetCdnSpaceIdResponse) Reset()
- func (m *GetCdnSpaceIdResponse) SizeVT() (n int)
- func (x *GetCdnSpaceIdResponse) String() string
- func (x *GetCdnSpaceIdResponse) UnmarshalJSON(b []byte) error
- func (x *GetCdnSpaceIdResponse) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *GetCdnSpaceIdResponse) UnmarshalVT(dAtA []byte) error
- type MountCdnSpaceRequest
- func (m *MountCdnSpaceRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *MountCdnSpaceRequest) CloneVT() *MountCdnSpaceRequest
- func (this *MountCdnSpaceRequest) EqualMessageVT(thatMsg any) bool
- func (this *MountCdnSpaceRequest) EqualVT(that *MountCdnSpaceRequest) bool
- func (x *MountCdnSpaceRequest) MarshalJSON() ([]byte, error)
- func (x *MountCdnSpaceRequest) MarshalProtoJSON(s *json.MarshalState)
- func (x *MountCdnSpaceRequest) MarshalProtoText() string
- func (m *MountCdnSpaceRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *MountCdnSpaceRequest) MarshalToVT(dAtA []byte) (int, error)
- func (m *MountCdnSpaceRequest) MarshalVT() (dAtA []byte, err error)
- func (*MountCdnSpaceRequest) ProtoMessage()
- func (x *MountCdnSpaceRequest) Reset()
- func (m *MountCdnSpaceRequest) SizeVT() (n int)
- func (x *MountCdnSpaceRequest) String() string
- func (x *MountCdnSpaceRequest) UnmarshalJSON(b []byte) error
- func (x *MountCdnSpaceRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *MountCdnSpaceRequest) UnmarshalVT(dAtA []byte) error
- type MountCdnSpaceResponse
- func (m *MountCdnSpaceResponse) CloneMessageVT() protobuf_go_lite.CloneMessage
- func (m *MountCdnSpaceResponse) CloneVT() *MountCdnSpaceResponse
- func (this *MountCdnSpaceResponse) EqualMessageVT(thatMsg any) bool
- func (this *MountCdnSpaceResponse) EqualVT(that *MountCdnSpaceResponse) bool
- func (x *MountCdnSpaceResponse) GetResourceId() uint32
- func (x *MountCdnSpaceResponse) MarshalJSON() ([]byte, error)
- func (x *MountCdnSpaceResponse) MarshalProtoJSON(s *json.MarshalState)
- func (x *MountCdnSpaceResponse) MarshalProtoText() string
- func (m *MountCdnSpaceResponse) MarshalToSizedBufferVT(dAtA []byte) (int, error)
- func (m *MountCdnSpaceResponse) MarshalToVT(dAtA []byte) (int, error)
- func (m *MountCdnSpaceResponse) MarshalVT() (dAtA []byte, err error)
- func (*MountCdnSpaceResponse) ProtoMessage()
- func (x *MountCdnSpaceResponse) Reset()
- func (m *MountCdnSpaceResponse) SizeVT() (n int)
- func (x *MountCdnSpaceResponse) String() string
- func (x *MountCdnSpaceResponse) UnmarshalJSON(b []byte) error
- func (x *MountCdnSpaceResponse) UnmarshalProtoJSON(s *json.UnmarshalState)
- func (m *MountCdnSpaceResponse) UnmarshalVT(dAtA []byte) error
- type SRPCCdnResourceServiceClient
- type SRPCCdnResourceServiceHandler
- func (SRPCCdnResourceServiceHandler) GetMethodIDs() []string
- func (d *SRPCCdnResourceServiceHandler) GetServiceID() string
- func (d *SRPCCdnResourceServiceHandler) InvokeMethod(serviceID, methodID string, strm srpc.Stream) (bool, error)
- func (SRPCCdnResourceServiceHandler) InvokeMethod_CopyV86ImageToSpace(impl SRPCCdnResourceServiceServer, strm srpc.Stream) error
- func (SRPCCdnResourceServiceHandler) InvokeMethod_GetCdnSpaceId(impl SRPCCdnResourceServiceServer, strm srpc.Stream) error
- func (SRPCCdnResourceServiceHandler) InvokeMethod_MountCdnSpace(impl SRPCCdnResourceServiceServer, strm srpc.Stream) error
- type SRPCCdnResourceServiceServer
- type SRPCCdnResourceService_CopyV86ImageToSpaceClient
- type SRPCCdnResourceService_CopyV86ImageToSpaceStream
- type SRPCCdnResourceService_GetCdnSpaceIdStream
- type SRPCCdnResourceService_MountCdnSpaceStream
Constants ¶
const SRPCCdnResourceServiceServiceID = "s4wave.cdn.CdnResourceService"
Variables ¶
var ( CopyV86ImageToSpaceStage_name = map[int32]string{ 0: "CopyV86ImageToSpaceStage_FETCHING", 1: "CopyV86ImageToSpaceStage_COPYING", 2: "CopyV86ImageToSpaceStage_DONE", } CopyV86ImageToSpaceStage_value = map[string]int32{ "CopyV86ImageToSpaceStage_FETCHING": 0, "CopyV86ImageToSpaceStage_COPYING": 1, "CopyV86ImageToSpaceStage_DONE": 2, } )
Enum value maps for CopyV86ImageToSpaceStage.
Functions ¶
func NewSRPCCdnResourceServiceHandler ¶
func NewSRPCCdnResourceServiceHandler(impl SRPCCdnResourceServiceServer, serviceID string) srpc.Handler
NewSRPCCdnResourceServiceHandler constructs a new RPC handler. serviceID: if empty, uses default: s4wave.cdn.CdnResourceService
func SRPCRegisterCdnResourceService ¶
func SRPCRegisterCdnResourceService(mux srpc.Mux, impl SRPCCdnResourceServiceServer) error
SRPCRegisterCdnResourceService registers the implementation with the mux. Uses the default serviceID: s4wave.cdn.CdnResourceService
Types ¶
type CopyV86ImageToSpaceProgress ¶ added in v0.56.1
type CopyV86ImageToSpaceProgress struct {
// Stage is the current server-owned image-copy stage.
Stage CopyV86ImageToSpaceStage `protobuf:"varint,1,opt,name=stage,proto3" json:"stage,omitempty"`
// BlocksSeen counts unique eligible source blocks encountered.
BlocksSeen uint64 `protobuf:"varint,2,opt,name=blocks_seen,json=blocksSeen,proto3" json:"blocksSeen,omitempty"`
// BlocksCopied counts source blocks processed by the destination store.
BlocksCopied uint64 `protobuf:"varint,3,opt,name=blocks_copied,json=blocksCopied,proto3" json:"blocksCopied,omitempty"`
// BlocksWritten counts source blocks newly written to the destination.
BlocksWritten uint64 `protobuf:"varint,4,opt,name=blocks_written,json=blocksWritten,proto3" json:"blocksWritten,omitempty"`
// LogicalSourceBytes counts eligible source bytes before destination dedupe.
LogicalSourceBytes uint64 `protobuf:"varint,5,opt,name=logical_source_bytes,json=logicalSourceBytes,proto3" json:"logicalSourceBytes,omitempty"`
// contains filtered or unexported fields
}
CopyV86ImageToSpaceProgress reports cumulative logical copy accounting.
func (*CopyV86ImageToSpaceProgress) CloneMessageVT ¶ added in v0.56.1
func (m *CopyV86ImageToSpaceProgress) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*CopyV86ImageToSpaceProgress) CloneVT ¶ added in v0.56.1
func (m *CopyV86ImageToSpaceProgress) CloneVT() *CopyV86ImageToSpaceProgress
func (*CopyV86ImageToSpaceProgress) EqualMessageVT ¶ added in v0.56.1
func (this *CopyV86ImageToSpaceProgress) EqualMessageVT(thatMsg any) bool
func (*CopyV86ImageToSpaceProgress) EqualVT ¶ added in v0.56.1
func (this *CopyV86ImageToSpaceProgress) EqualVT(that *CopyV86ImageToSpaceProgress) bool
func (*CopyV86ImageToSpaceProgress) GetBlocksCopied ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) GetBlocksCopied() uint64
func (*CopyV86ImageToSpaceProgress) GetBlocksSeen ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) GetBlocksSeen() uint64
func (*CopyV86ImageToSpaceProgress) GetBlocksWritten ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) GetBlocksWritten() uint64
func (*CopyV86ImageToSpaceProgress) GetLogicalSourceBytes ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) GetLogicalSourceBytes() uint64
func (*CopyV86ImageToSpaceProgress) GetStage ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) GetStage() CopyV86ImageToSpaceStage
func (*CopyV86ImageToSpaceProgress) MarshalJSON ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) MarshalJSON() ([]byte, error)
MarshalJSON marshals the CopyV86ImageToSpaceProgress to JSON.
func (*CopyV86ImageToSpaceProgress) MarshalProtoJSON ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the CopyV86ImageToSpaceProgress message to JSON.
func (*CopyV86ImageToSpaceProgress) MarshalProtoText ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) MarshalProtoText() string
func (*CopyV86ImageToSpaceProgress) MarshalToSizedBufferVT ¶ added in v0.56.1
func (m *CopyV86ImageToSpaceProgress) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*CopyV86ImageToSpaceProgress) MarshalToVT ¶ added in v0.56.1
func (m *CopyV86ImageToSpaceProgress) MarshalToVT(dAtA []byte) (int, error)
func (*CopyV86ImageToSpaceProgress) MarshalVT ¶ added in v0.56.1
func (m *CopyV86ImageToSpaceProgress) MarshalVT() (dAtA []byte, err error)
func (*CopyV86ImageToSpaceProgress) ProtoMessage ¶ added in v0.56.1
func (*CopyV86ImageToSpaceProgress) ProtoMessage()
func (*CopyV86ImageToSpaceProgress) Reset ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) Reset()
func (*CopyV86ImageToSpaceProgress) SizeVT ¶ added in v0.56.1
func (m *CopyV86ImageToSpaceProgress) SizeVT() (n int)
func (*CopyV86ImageToSpaceProgress) String ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) String() string
func (*CopyV86ImageToSpaceProgress) UnmarshalJSON ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the CopyV86ImageToSpaceProgress from JSON.
func (*CopyV86ImageToSpaceProgress) UnmarshalProtoJSON ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceProgress) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the CopyV86ImageToSpaceProgress message from JSON.
func (*CopyV86ImageToSpaceProgress) UnmarshalVT ¶ added in v0.56.1
func (m *CopyV86ImageToSpaceProgress) UnmarshalVT(dAtA []byte) error
type CopyV86ImageToSpaceRequest ¶ added in v0.51.0
type CopyV86ImageToSpaceRequest struct {
// SessionIdx is the caller's session index; used to resolve the
// destination user Space via the standard session-aware mount path.
SessionIdx uint32 `protobuf:"varint,1,opt,name=session_idx,json=sessionIdx,proto3" json:"sessionIdx,omitempty"`
// DstSpaceId is the ULID of the user Space the V86Image will land in.
DstSpaceId string `protobuf:"bytes,2,opt,name=dst_space_id,json=dstSpaceId,proto3" json:"dstSpaceId,omitempty"`
// SrcObjectKey is the V86Image object key in the CDN Space.
SrcObjectKey string `protobuf:"bytes,3,opt,name=src_object_key,json=srcObjectKey,proto3" json:"srcObjectKey,omitempty"`
// DstObjectKey is the object key in the destination Space.
DstObjectKey string `protobuf:"bytes,4,opt,name=dst_object_key,json=dstObjectKey,proto3" json:"dstObjectKey,omitempty"`
// contains filtered or unexported fields
}
CopyV86ImageToSpaceRequest is the request type for CopyV86ImageToSpace.
func (*CopyV86ImageToSpaceRequest) CloneMessageVT ¶ added in v0.51.0
func (m *CopyV86ImageToSpaceRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*CopyV86ImageToSpaceRequest) CloneVT ¶ added in v0.51.0
func (m *CopyV86ImageToSpaceRequest) CloneVT() *CopyV86ImageToSpaceRequest
func (*CopyV86ImageToSpaceRequest) EqualMessageVT ¶ added in v0.51.0
func (this *CopyV86ImageToSpaceRequest) EqualMessageVT(thatMsg any) bool
func (*CopyV86ImageToSpaceRequest) EqualVT ¶ added in v0.51.0
func (this *CopyV86ImageToSpaceRequest) EqualVT(that *CopyV86ImageToSpaceRequest) bool
func (*CopyV86ImageToSpaceRequest) GetDstObjectKey ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) GetDstObjectKey() string
func (*CopyV86ImageToSpaceRequest) GetDstSpaceId ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) GetDstSpaceId() string
func (*CopyV86ImageToSpaceRequest) GetSessionIdx ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) GetSessionIdx() uint32
func (*CopyV86ImageToSpaceRequest) GetSrcObjectKey ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) GetSrcObjectKey() string
func (*CopyV86ImageToSpaceRequest) MarshalJSON ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) MarshalJSON() ([]byte, error)
MarshalJSON marshals the CopyV86ImageToSpaceRequest to JSON.
func (*CopyV86ImageToSpaceRequest) MarshalProtoJSON ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the CopyV86ImageToSpaceRequest message to JSON.
func (*CopyV86ImageToSpaceRequest) MarshalProtoText ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) MarshalProtoText() string
func (*CopyV86ImageToSpaceRequest) MarshalToSizedBufferVT ¶ added in v0.51.0
func (m *CopyV86ImageToSpaceRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*CopyV86ImageToSpaceRequest) MarshalToVT ¶ added in v0.51.0
func (m *CopyV86ImageToSpaceRequest) MarshalToVT(dAtA []byte) (int, error)
func (*CopyV86ImageToSpaceRequest) MarshalVT ¶ added in v0.51.0
func (m *CopyV86ImageToSpaceRequest) MarshalVT() (dAtA []byte, err error)
func (*CopyV86ImageToSpaceRequest) ProtoMessage ¶ added in v0.51.0
func (*CopyV86ImageToSpaceRequest) ProtoMessage()
func (*CopyV86ImageToSpaceRequest) Reset ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) Reset()
func (*CopyV86ImageToSpaceRequest) SizeVT ¶ added in v0.51.0
func (m *CopyV86ImageToSpaceRequest) SizeVT() (n int)
func (*CopyV86ImageToSpaceRequest) String ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) String() string
func (*CopyV86ImageToSpaceRequest) UnmarshalJSON ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the CopyV86ImageToSpaceRequest from JSON.
func (*CopyV86ImageToSpaceRequest) UnmarshalProtoJSON ¶ added in v0.51.0
func (x *CopyV86ImageToSpaceRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the CopyV86ImageToSpaceRequest message from JSON.
func (*CopyV86ImageToSpaceRequest) UnmarshalVT ¶ added in v0.51.0
func (m *CopyV86ImageToSpaceRequest) UnmarshalVT(dAtA []byte) error
type CopyV86ImageToSpaceStage ¶ added in v0.56.1
type CopyV86ImageToSpaceStage int32
CopyV86ImageToSpaceStage is the server-owned CDN image-copy stage.
const ( CopyV86ImageToSpaceStage_CopyV86ImageToSpaceStage_FETCHING CopyV86ImageToSpaceStage = 0 CopyV86ImageToSpaceStage_CopyV86ImageToSpaceStage_COPYING CopyV86ImageToSpaceStage = 1 CopyV86ImageToSpaceStage_CopyV86ImageToSpaceStage_DONE CopyV86ImageToSpaceStage = 2 )
func (CopyV86ImageToSpaceStage) Enum ¶ added in v0.56.1
func (x CopyV86ImageToSpaceStage) Enum() *CopyV86ImageToSpaceStage
func (CopyV86ImageToSpaceStage) MarshalJSON ¶ added in v0.56.1
func (x CopyV86ImageToSpaceStage) MarshalJSON() ([]byte, error)
MarshalJSON marshals the CopyV86ImageToSpaceStage to JSON.
func (CopyV86ImageToSpaceStage) MarshalProtoJSON ¶ added in v0.56.1
func (x CopyV86ImageToSpaceStage) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the CopyV86ImageToSpaceStage to JSON.
func (CopyV86ImageToSpaceStage) MarshalProtoText ¶ added in v0.56.1
func (x CopyV86ImageToSpaceStage) MarshalProtoText() string
func (CopyV86ImageToSpaceStage) MarshalText ¶ added in v0.56.1
func (x CopyV86ImageToSpaceStage) MarshalText() ([]byte, error)
MarshalText marshals the CopyV86ImageToSpaceStage to text.
func (CopyV86ImageToSpaceStage) String ¶ added in v0.56.1
func (x CopyV86ImageToSpaceStage) String() string
func (*CopyV86ImageToSpaceStage) UnmarshalJSON ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceStage) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the CopyV86ImageToSpaceStage from JSON.
func (*CopyV86ImageToSpaceStage) UnmarshalProtoJSON ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceStage) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the CopyV86ImageToSpaceStage from JSON.
func (*CopyV86ImageToSpaceStage) UnmarshalText ¶ added in v0.56.1
func (x *CopyV86ImageToSpaceStage) UnmarshalText(b []byte) error
UnmarshalText unmarshals the CopyV86ImageToSpaceStage from text.
type GetCdnSpaceIdRequest ¶
type GetCdnSpaceIdRequest struct {
// contains filtered or unexported fields
}
GetCdnSpaceIdRequest is the request type for GetCdnSpaceId.
func (*GetCdnSpaceIdRequest) CloneMessageVT ¶
func (m *GetCdnSpaceIdRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*GetCdnSpaceIdRequest) CloneVT ¶
func (m *GetCdnSpaceIdRequest) CloneVT() *GetCdnSpaceIdRequest
func (*GetCdnSpaceIdRequest) EqualMessageVT ¶
func (this *GetCdnSpaceIdRequest) EqualMessageVT(thatMsg any) bool
func (*GetCdnSpaceIdRequest) EqualVT ¶
func (this *GetCdnSpaceIdRequest) EqualVT(that *GetCdnSpaceIdRequest) bool
func (*GetCdnSpaceIdRequest) MarshalJSON ¶
func (x *GetCdnSpaceIdRequest) MarshalJSON() ([]byte, error)
MarshalJSON marshals the GetCdnSpaceIdRequest to JSON.
func (*GetCdnSpaceIdRequest) MarshalProtoJSON ¶
func (x *GetCdnSpaceIdRequest) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the GetCdnSpaceIdRequest message to JSON.
func (*GetCdnSpaceIdRequest) MarshalProtoText ¶
func (x *GetCdnSpaceIdRequest) MarshalProtoText() string
func (*GetCdnSpaceIdRequest) MarshalToSizedBufferVT ¶
func (m *GetCdnSpaceIdRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*GetCdnSpaceIdRequest) MarshalToVT ¶
func (m *GetCdnSpaceIdRequest) MarshalToVT(dAtA []byte) (int, error)
func (*GetCdnSpaceIdRequest) MarshalVT ¶
func (m *GetCdnSpaceIdRequest) MarshalVT() (dAtA []byte, err error)
func (*GetCdnSpaceIdRequest) ProtoMessage ¶
func (*GetCdnSpaceIdRequest) ProtoMessage()
func (*GetCdnSpaceIdRequest) Reset ¶
func (x *GetCdnSpaceIdRequest) Reset()
func (*GetCdnSpaceIdRequest) SizeVT ¶
func (m *GetCdnSpaceIdRequest) SizeVT() (n int)
func (*GetCdnSpaceIdRequest) String ¶
func (x *GetCdnSpaceIdRequest) String() string
func (*GetCdnSpaceIdRequest) UnmarshalJSON ¶
func (x *GetCdnSpaceIdRequest) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the GetCdnSpaceIdRequest from JSON.
func (*GetCdnSpaceIdRequest) UnmarshalProtoJSON ¶
func (x *GetCdnSpaceIdRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the GetCdnSpaceIdRequest message from JSON.
func (*GetCdnSpaceIdRequest) UnmarshalVT ¶
func (m *GetCdnSpaceIdRequest) UnmarshalVT(dAtA []byte) error
type GetCdnSpaceIdResponse ¶
type GetCdnSpaceIdResponse struct {
// SpaceId is the CDN Space ULID.
SpaceId string `protobuf:"bytes,1,opt,name=space_id,json=spaceId,proto3" json:"spaceId,omitempty"`
// contains filtered or unexported fields
}
GetCdnSpaceIdResponse is the response type for GetCdnSpaceId.
func (*GetCdnSpaceIdResponse) CloneMessageVT ¶
func (m *GetCdnSpaceIdResponse) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*GetCdnSpaceIdResponse) CloneVT ¶
func (m *GetCdnSpaceIdResponse) CloneVT() *GetCdnSpaceIdResponse
func (*GetCdnSpaceIdResponse) EqualMessageVT ¶
func (this *GetCdnSpaceIdResponse) EqualMessageVT(thatMsg any) bool
func (*GetCdnSpaceIdResponse) EqualVT ¶
func (this *GetCdnSpaceIdResponse) EqualVT(that *GetCdnSpaceIdResponse) bool
func (*GetCdnSpaceIdResponse) GetSpaceId ¶
func (x *GetCdnSpaceIdResponse) GetSpaceId() string
func (*GetCdnSpaceIdResponse) MarshalJSON ¶
func (x *GetCdnSpaceIdResponse) MarshalJSON() ([]byte, error)
MarshalJSON marshals the GetCdnSpaceIdResponse to JSON.
func (*GetCdnSpaceIdResponse) MarshalProtoJSON ¶
func (x *GetCdnSpaceIdResponse) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the GetCdnSpaceIdResponse message to JSON.
func (*GetCdnSpaceIdResponse) MarshalProtoText ¶
func (x *GetCdnSpaceIdResponse) MarshalProtoText() string
func (*GetCdnSpaceIdResponse) MarshalToSizedBufferVT ¶
func (m *GetCdnSpaceIdResponse) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*GetCdnSpaceIdResponse) MarshalToVT ¶
func (m *GetCdnSpaceIdResponse) MarshalToVT(dAtA []byte) (int, error)
func (*GetCdnSpaceIdResponse) MarshalVT ¶
func (m *GetCdnSpaceIdResponse) MarshalVT() (dAtA []byte, err error)
func (*GetCdnSpaceIdResponse) ProtoMessage ¶
func (*GetCdnSpaceIdResponse) ProtoMessage()
func (*GetCdnSpaceIdResponse) Reset ¶
func (x *GetCdnSpaceIdResponse) Reset()
func (*GetCdnSpaceIdResponse) SizeVT ¶
func (m *GetCdnSpaceIdResponse) SizeVT() (n int)
func (*GetCdnSpaceIdResponse) String ¶
func (x *GetCdnSpaceIdResponse) String() string
func (*GetCdnSpaceIdResponse) UnmarshalJSON ¶
func (x *GetCdnSpaceIdResponse) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the GetCdnSpaceIdResponse from JSON.
func (*GetCdnSpaceIdResponse) UnmarshalProtoJSON ¶
func (x *GetCdnSpaceIdResponse) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the GetCdnSpaceIdResponse message from JSON.
func (*GetCdnSpaceIdResponse) UnmarshalVT ¶
func (m *GetCdnSpaceIdResponse) UnmarshalVT(dAtA []byte) error
type MountCdnSpaceRequest ¶
type MountCdnSpaceRequest struct {
// contains filtered or unexported fields
}
MountCdnSpaceRequest is the request type for MountCdnSpace.
func (*MountCdnSpaceRequest) CloneMessageVT ¶
func (m *MountCdnSpaceRequest) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*MountCdnSpaceRequest) CloneVT ¶
func (m *MountCdnSpaceRequest) CloneVT() *MountCdnSpaceRequest
func (*MountCdnSpaceRequest) EqualMessageVT ¶
func (this *MountCdnSpaceRequest) EqualMessageVT(thatMsg any) bool
func (*MountCdnSpaceRequest) EqualVT ¶
func (this *MountCdnSpaceRequest) EqualVT(that *MountCdnSpaceRequest) bool
func (*MountCdnSpaceRequest) MarshalJSON ¶
func (x *MountCdnSpaceRequest) MarshalJSON() ([]byte, error)
MarshalJSON marshals the MountCdnSpaceRequest to JSON.
func (*MountCdnSpaceRequest) MarshalProtoJSON ¶
func (x *MountCdnSpaceRequest) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the MountCdnSpaceRequest message to JSON.
func (*MountCdnSpaceRequest) MarshalProtoText ¶
func (x *MountCdnSpaceRequest) MarshalProtoText() string
func (*MountCdnSpaceRequest) MarshalToSizedBufferVT ¶
func (m *MountCdnSpaceRequest) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*MountCdnSpaceRequest) MarshalToVT ¶
func (m *MountCdnSpaceRequest) MarshalToVT(dAtA []byte) (int, error)
func (*MountCdnSpaceRequest) MarshalVT ¶
func (m *MountCdnSpaceRequest) MarshalVT() (dAtA []byte, err error)
func (*MountCdnSpaceRequest) ProtoMessage ¶
func (*MountCdnSpaceRequest) ProtoMessage()
func (*MountCdnSpaceRequest) Reset ¶
func (x *MountCdnSpaceRequest) Reset()
func (*MountCdnSpaceRequest) SizeVT ¶
func (m *MountCdnSpaceRequest) SizeVT() (n int)
func (*MountCdnSpaceRequest) String ¶
func (x *MountCdnSpaceRequest) String() string
func (*MountCdnSpaceRequest) UnmarshalJSON ¶
func (x *MountCdnSpaceRequest) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the MountCdnSpaceRequest from JSON.
func (*MountCdnSpaceRequest) UnmarshalProtoJSON ¶
func (x *MountCdnSpaceRequest) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the MountCdnSpaceRequest message from JSON.
func (*MountCdnSpaceRequest) UnmarshalVT ¶
func (m *MountCdnSpaceRequest) UnmarshalVT(dAtA []byte) error
type MountCdnSpaceResponse ¶
type MountCdnSpaceResponse struct {
// ResourceId is the client resource id of the mounted SpaceResource.
ResourceId uint32 `protobuf:"varint,1,opt,name=resource_id,json=resourceId,proto3" json:"resourceId,omitempty"`
// contains filtered or unexported fields
}
MountCdnSpaceResponse is the response type for MountCdnSpace.
func (*MountCdnSpaceResponse) CloneMessageVT ¶
func (m *MountCdnSpaceResponse) CloneMessageVT() protobuf_go_lite.CloneMessage
func (*MountCdnSpaceResponse) CloneVT ¶
func (m *MountCdnSpaceResponse) CloneVT() *MountCdnSpaceResponse
func (*MountCdnSpaceResponse) EqualMessageVT ¶
func (this *MountCdnSpaceResponse) EqualMessageVT(thatMsg any) bool
func (*MountCdnSpaceResponse) EqualVT ¶
func (this *MountCdnSpaceResponse) EqualVT(that *MountCdnSpaceResponse) bool
func (*MountCdnSpaceResponse) GetResourceId ¶
func (x *MountCdnSpaceResponse) GetResourceId() uint32
func (*MountCdnSpaceResponse) MarshalJSON ¶
func (x *MountCdnSpaceResponse) MarshalJSON() ([]byte, error)
MarshalJSON marshals the MountCdnSpaceResponse to JSON.
func (*MountCdnSpaceResponse) MarshalProtoJSON ¶
func (x *MountCdnSpaceResponse) MarshalProtoJSON(s *json.MarshalState)
MarshalProtoJSON marshals the MountCdnSpaceResponse message to JSON.
func (*MountCdnSpaceResponse) MarshalProtoText ¶
func (x *MountCdnSpaceResponse) MarshalProtoText() string
func (*MountCdnSpaceResponse) MarshalToSizedBufferVT ¶
func (m *MountCdnSpaceResponse) MarshalToSizedBufferVT(dAtA []byte) (int, error)
func (*MountCdnSpaceResponse) MarshalToVT ¶
func (m *MountCdnSpaceResponse) MarshalToVT(dAtA []byte) (int, error)
func (*MountCdnSpaceResponse) MarshalVT ¶
func (m *MountCdnSpaceResponse) MarshalVT() (dAtA []byte, err error)
func (*MountCdnSpaceResponse) ProtoMessage ¶
func (*MountCdnSpaceResponse) ProtoMessage()
func (*MountCdnSpaceResponse) Reset ¶
func (x *MountCdnSpaceResponse) Reset()
func (*MountCdnSpaceResponse) SizeVT ¶
func (m *MountCdnSpaceResponse) SizeVT() (n int)
func (*MountCdnSpaceResponse) String ¶
func (x *MountCdnSpaceResponse) String() string
func (*MountCdnSpaceResponse) UnmarshalJSON ¶
func (x *MountCdnSpaceResponse) UnmarshalJSON(b []byte) error
UnmarshalJSON unmarshals the MountCdnSpaceResponse from JSON.
func (*MountCdnSpaceResponse) UnmarshalProtoJSON ¶
func (x *MountCdnSpaceResponse) UnmarshalProtoJSON(s *json.UnmarshalState)
UnmarshalProtoJSON unmarshals the MountCdnSpaceResponse message from JSON.
func (*MountCdnSpaceResponse) UnmarshalVT ¶
func (m *MountCdnSpaceResponse) UnmarshalVT(dAtA []byte) error
type SRPCCdnResourceServiceClient ¶
type SRPCCdnResourceServiceClient interface {
// SRPCClient returns the underlying SRPC client.
SRPCClient() srpc.Client
GetCdnSpaceId(ctx context.Context, in *GetCdnSpaceIdRequest) (*GetCdnSpaceIdResponse, error)
MountCdnSpace(ctx context.Context, in *MountCdnSpaceRequest) (*MountCdnSpaceResponse, error)
CopyV86ImageToSpace(ctx context.Context, in *CopyV86ImageToSpaceRequest) (SRPCCdnResourceService_CopyV86ImageToSpaceClient, error)
}
func NewSRPCCdnResourceServiceClient ¶
func NewSRPCCdnResourceServiceClient(cc srpc.Client) SRPCCdnResourceServiceClient
func NewSRPCCdnResourceServiceClientWithServiceID ¶
func NewSRPCCdnResourceServiceClientWithServiceID(cc srpc.Client, serviceID string) SRPCCdnResourceServiceClient
type SRPCCdnResourceServiceHandler ¶
type SRPCCdnResourceServiceHandler struct {
// contains filtered or unexported fields
}
func (SRPCCdnResourceServiceHandler) GetMethodIDs ¶
func (SRPCCdnResourceServiceHandler) GetMethodIDs() []string
func (*SRPCCdnResourceServiceHandler) GetServiceID ¶
func (d *SRPCCdnResourceServiceHandler) GetServiceID() string
func (*SRPCCdnResourceServiceHandler) InvokeMethod ¶
func (SRPCCdnResourceServiceHandler) InvokeMethod_CopyV86ImageToSpace ¶ added in v0.51.0
func (SRPCCdnResourceServiceHandler) InvokeMethod_CopyV86ImageToSpace(impl SRPCCdnResourceServiceServer, strm srpc.Stream) error
func (SRPCCdnResourceServiceHandler) InvokeMethod_GetCdnSpaceId ¶
func (SRPCCdnResourceServiceHandler) InvokeMethod_GetCdnSpaceId(impl SRPCCdnResourceServiceServer, strm srpc.Stream) error
func (SRPCCdnResourceServiceHandler) InvokeMethod_MountCdnSpace ¶
func (SRPCCdnResourceServiceHandler) InvokeMethod_MountCdnSpace(impl SRPCCdnResourceServiceServer, strm srpc.Stream) error
type SRPCCdnResourceServiceServer ¶
type SRPCCdnResourceServiceServer interface {
GetCdnSpaceId(context.Context, *GetCdnSpaceIdRequest) (*GetCdnSpaceIdResponse, error)
MountCdnSpace(context.Context, *MountCdnSpaceRequest) (*MountCdnSpaceResponse, error)
CopyV86ImageToSpace(*CopyV86ImageToSpaceRequest, SRPCCdnResourceService_CopyV86ImageToSpaceStream) error
}
type SRPCCdnResourceService_CopyV86ImageToSpaceClient ¶ added in v0.56.1
type SRPCCdnResourceService_CopyV86ImageToSpaceClient interface {
srpc.Stream
Recv() (*CopyV86ImageToSpaceProgress, error)
RecvTo(*CopyV86ImageToSpaceProgress) error
}
type SRPCCdnResourceService_CopyV86ImageToSpaceStream ¶ added in v0.51.0
type SRPCCdnResourceService_CopyV86ImageToSpaceStream interface {
srpc.Stream
Send(*CopyV86ImageToSpaceProgress) error
SendAndClose(*CopyV86ImageToSpaceProgress) error
}